@@ -44,7 +44,7 @@ struct _Sipomatic
 
 typedef struct _Sipomatic Sipomatic;
 	
-void sipomatic_init(Sipomatic *obj, gchar *url);
+void sipomatic_init(Sipomatic *obj, gchar *url, gboolean ipv6);
 void sipomatic_uninit(Sipomatic *obj);
 void sipomatic_iterate(Sipomatic *obj);
 #define sipomatic_lock(obj) g_mutex_lock((obj)->lock);
@@ -52,6 +52,15 @@ void sipomatic_iterate(Sipomatic *obj);
 
 void sipomatic_set_annouce_file(Sipomatic *obj, char *file);
 
+struct stream_params{
+	gint ncodecs;
+	gint line;
+	gint localport;
+	gint remoteport;
+	gint pt;
+	gchar *remaddr;
+};
+
 struct _Call
 {
 	Sipomatic *root;
@@ -59,16 +68,15 @@ struct _Call
 	GTimer *timer;
 	int did;
 	AudioStream *audio_stream;
+#ifdef VIDEO_ENABLED
+	VideoStream *video_stream;
+#endif
 	gint state;
 	struct _CallParams *params;
 	gint eof;
 	RtpProfile *profile;
-	gint ncodecs;
-	gint line;
-	gint localport;
-	gint remoteport;
-	gint pt;
-	gchar *remaddr;
+	struct stream_params audio;
+	struct stream_params video;
 };
 
 #define CALL_STATE_INIT 0
