@@ -23,6 +23,7 @@
  */
  
 #include "linphonecore.h"
+#include "private.h"
 #include "misc.h"
 #include <eXosip.h>
 #include <osipparser2/osip_message.h>
@@ -158,11 +159,12 @@ void linphone_core_add_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info)
 
 void linphone_core_remove_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info){
 	int len=g_list_length(lc->auth_info);
+	int newlen;
 	int i;
 	GList *elem;
-	elem=g_list_find(lc->auth_info,(gconstpointer)info);
-	g_return_if_fail(elem!=NULL);
-	lc->auth_info=g_list_remove_link(lc->auth_info,elem);
+	lc->auth_info=g_list_remove(lc->auth_info,(gconstpointer)info);
+	newlen=g_list_length(lc->auth_info);
+	/*printf("len=%i newlen=%i\n",len,newlen);*/
 	linphone_auth_info_destroy(info);
 	for (i=0;i<len;i++){
 		linphone_auth_info_write_config(lc->config,NULL,i);
@@ -185,6 +187,7 @@ void linphone_core_clear_all_auth_info(LinphoneCore *lc){
 		linphone_auth_info_write_config(lc->config,NULL,i);
 	}
 	g_list_free(lc->auth_info);
+	lc->auth_info=NULL;
 }
 
 gboolean linphone_core_find_or_ask_for_auth_info(LinphoneCore *lc,const char *username,const char* realm, gboolean force_ask)
@@ -246,7 +249,7 @@ void linphone_register_authentication_required(LinphoneCore *lc,eXosip_event_t *
 	if (linphone_process_authentication(lc,resp,cfg,cfg->auth_pending)){
 		/* we have the information, so retry the register */
 		eXosip_lock();
-		eXosip_register(ev->rid,cfg->expires);
+		eXosip_register(ev->rid,-1);
 		eXosip_unlock();
 	}
 	cfg->auth_pending=TRUE;
