@@ -70,6 +70,7 @@ int linphone_call_accepted(LinphoneCore *lc,int id, const char *sdpbody)
 		lc->ringstream=NULL;
 	}
 	linphone_core_start_media_streams(lc,call);
+	
 	return 0;
 }
 
@@ -285,17 +286,6 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 	switch(status)
 	{
 		case 200:
-			{
-				char *tmp;
-				if (from_2char_without_params(from_url,&tmp)==0){
-					barmesg=g_strdup_printf("%s %s",tmp,contacted);
-					lc->vtable.show(lc);
-					lc->vtable.display_status(lc,barmesg);
-					lc->vtable.inv_recv(lc,(char*)tmp);
-					g_free(barmesg);
-					osip_free(tmp);
-				}
-			}
 			/* vérification de la qos */
 #ifdef VINCENT_MAURY_RSVP
 			if (strcmp(textinfo,"With QoS")==0 && !lc->rsvp_enable)
@@ -337,6 +327,17 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 			}else g_warning("Could not start local ring !");
 #endif
 			linphone_call_set_state(lc->call,LCStateRinging);
+			{
+				char *tmp;
+				if (from_2char_without_params(from_url,&tmp)==0){
+					barmesg=g_strdup_printf("%s %s",tmp,contacted);
+					lc->vtable.show(lc);
+					lc->vtable.display_status(lc,barmesg);
+					lc->vtable.inv_recv(lc,tmp);
+					g_free(barmesg);
+					osip_free(tmp);
+				}
+			}
 		break;
 		default:	
 			if (status==-1) status=415;
@@ -404,8 +405,11 @@ int linphone_set_audio_offer(sdp_context_t *ctx)
 			payload.pt=rtp_profile_get_payload_number_from_rtpmap(lc->local_profile,payload.a_rtpmap);
 			payload.localport=lc->rtp_conf.audio_rtp_port;
 			/* when setting speex, add a b=<AS>: to choose bitrate */
-			if (strcmp(codec->mime_type,"speex")==0){
+			if (strcasecmp(codec->mime_type,"speex")==0){
 				payload.b_as_bandwidth=codec->normal_bitrate/1000;
+			}else if (strcasecmp(codec->mime_type,"iLBC")==0){
+				/* prefer the 30 ms mode */
+				payload.a_fmtp="ptime=30";
 			}
 			sdp_context_add_audio_payload(ctx,&payload);
 			g_free(payload.a_rtpmap);
@@ -487,12 +491,17 @@ SupportLevel linphone_payload_is_supported(sdp_payload_t *payload,RtpProfile *lo
 			rtppayload=payload_type_clone(rtppayload);
 			rtp_profile_set_payload(dialog_profile,payload->pt,rtppayload);
 			/* add to the rtp payload type some other parameters (bandwidth) */
-			if (payload->b_as_bandwidth!=0) rtppayload->normal_bitrate=payload->b_as_bandwidth*1000;
-			if (payload->a_fmtp!=NULL) rtppayload->fmtp=g_strdup(payload->a_fmtp);
-			else if (strcasecmp(rtppayload->mime_type,"iLBC")==0){
+			if (payload->b_as_bandwidth!=0)
+				rtppayload->normal_bitrate=payload->b_as_bandwidth*1000;
+			if (payload->a_fmtp!=NULL){
+				payload_type_set_send_fmtp(rtppayload,payload->a_fmtp);
+			}
+			if (strcasecmp(rtppayload->mime_type,"iLBC")==0){
 				/*default to 30 ms mode */
-				payload->a_fmtp="ptime=30";
-				rtppayload->fmtp=g_strdup(payload->a_fmtp);
+				if (payload->a_fmtp==NULL){
+					payload->a_fmtp="ptime=30";
+					payload_type_set_recv_fmtp(rtppayload,payload->a_fmtp);
+				}
 			}
 		}
 		return ret;
@@ -668,9 +677,10 @@ void linphone_registration_faillure(LinphoneCore *lc,eXosip_event_t *ev)
 			linphone_register_authentication_required(lc,ev);
 			break;
 		default:
-			if (strlen(ev->reason_phrase)==0) msg=_("Registration failed (timeout).");
+			if (strlen(ev->reason_phrase)==0) msg=g_strdup_printf(_("Registration on %s failed (timeout)."),ev->req_uri);
 			else msg=ev->reason_phrase;
 			lc->vtable.display_status(lc,msg);
+			if ( msg != ev->reason_phrase ) g_free(msg);
 	}
 	
 }
@@ -692,6 +702,8 @@ void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
 		case EXOSIP_CALL_ANSWERED:
 			g_message("CALL_ANSWERED\n");
 			linphone_call_accepted(lc,ev->did,ev->sdp_body);
+			/*send the ack once streams are started*/
+			eXosip_send_ack(ev->did);
 			break;
 		case EXOSIP_CALL_CLOSED:
 		case EXOSIP_CALL_CANCELLED:
