@@ -23,12 +23,11 @@
  */
 
 #include "linphonecore.h"
+#include "private.h"
 #include <eXosip.h>
 #include <osipparser2/osip_message.h>
 #include "lpconfig.h"
 
-extern int linphone_online_status_to_eXosip(LinphoneOnlineStatus os);
-void linphone_friend_destroy(LinphoneFriend *lf);
 
 static gint friend_data_compare(gconstpointer a, gconstpointer b, gpointer data){
 	osip_from_t *fa=((LinphoneFriend*)a)->url;
@@ -232,7 +231,6 @@ gchar * linphone_friend_get_url(LinphoneFriend *lf){
 
 
 void linphone_friend_apply(LinphoneFriend *fr, LinphoneCore *lc){
-	int err;
 	if (fr->url==NULL) {
 		g_warning("No sip url defined.");
 		return;
