@@ -139,7 +139,6 @@ LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, const char *from, co
 void linphone_call_destroy(LinphoneCall *obj)
 {
 	linphone_call_log_completed(obj->log,obj);
-	if (obj==NULL) return;
 	if (obj->profile!=NULL && obj->profile!=&av_profile) rtp_profile_destroy(obj->profile);
 	if (obj->sdpctx!=NULL) sdp_context_free(obj->sdpctx);
 	g_free(obj);
@@ -246,11 +245,9 @@ void linphone_core_enable_logs(FILE *file){
 				   __file_log_handler, NULL);
 		g_log_set_handler ("MediaStreamer", G_LOG_LEVEL_MASK,
 				   __file_log_handler, NULL);
-		g_log_set_handler ("oRTP", G_LOG_LEVEL_MASK,
-				   __file_log_handler, NULL);
-		g_log_set_handler ("oRTP-stats", G_LOG_LEVEL_MASK,
-				   __file_log_handler, NULL);
 	}
+	ortp_set_log_file(file);
+	ortp_set_log_level_mask(ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
 	osip_trace_initialize (OSIP_INFO4, file);
 }
 void linphone_core_disable_logs(){
@@ -262,11 +259,7 @@ void linphone_core_disable_logs(){
 	g_log_set_handler ("MediaStreamer",
 			   G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING,
 			   __null_log_handler, NULL);
-	g_log_set_handler ("oRTP",
-			   G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING,
-			   __null_log_handler, NULL);
-	g_log_set_handler ("oRTP-stats", G_LOG_LEVEL_MESSAGE,
-			   __null_log_handler, NULL);
+	ortp_set_log_level_mask(ORTP_ERROR|ORTP_FATAL);
 }
 
 
@@ -626,6 +619,9 @@ void sip_config_read(LinphoneCore *lc)
 	tmp=lp_config_get_int(lc->config,"net","use_nat",0);
 	linphone_core_set_nat_address(lc,tmpstr,tmp);		
 	
+	tmp=lp_config_get_int(lc->config,"sip","inc_timeout",15);
+	linphone_core_set_inc_timeout(lc,tmp);
+
 	/* get proxies config */
 	for(i=0;; i++){
 		LinphoneProxyConfig *cfg=linphone_proxy_config_new_from_config_file(lc->config,i);
@@ -1038,24 +1034,34 @@ void linphone_core_iterate(LinphoneCore *lc)
 	printf("entering linphone_core_iterate()\n");
 #endif
 	if (lc->preview_finished){
-    	lc->preview_finished=0;
-    	ring_stop(lc->ringstream);
-    	lc->ringstream=NULL;
-    	lc_callback_obj_invoke(&lc->preview_finished_cb,lc);
+		lc->preview_finished=0;
+		ring_stop(lc->ringstream);
+		lc->ringstream=NULL;
+		lc_callback_obj_invoke(&lc->preview_finished_cb,lc);
 		restore_sound_daemons();
 	}
 #ifdef AMD
 	printf("getting eXosip event...\n");
 #endif
 	
-	if (exosip_running)
-	  {
-	    while((ev=eXosip_event_wait(0,0))!=NULL){
-	      linphone_core_process_event(lc,ev);
-	    }
-	    linphone_core_update_proxy_register(lc);
-	    linphone_core_refresh_subscribes(lc);
-	  }
+	if (exosip_running){
+		while((ev=eXosip_event_wait(0,0))!=NULL){
+			linphone_core_process_event(lc,ev);
+		}
+		linphone_core_update_proxy_register(lc);
+		linphone_core_refresh_subscribes(lc);
+	}
+	if (lc->call!=NULL){
+		LinphoneCall *call=lc->call;
+		if (call->dir==LinphoneCallIncoming && call->state==LCStateRinging){
+			int elapsed=time(NULL)-call->start_time;
+			g_message("incoming call ringing for %i seconds",elapsed);
+			if (elapsed>lc->sip_conf.inc_timeout){
+				linphone_core_terminate_call(lc,NULL);
+			}
+		}
+	}
+
 #ifdef AMD
 	printf("iterate done...\n");
 #endif
@@ -1225,12 +1231,12 @@ int linphone_core_refer(LinphoneCore *lc, const char *url)
 {
     char *real_url=NULL;
     osip_to_t *real_parsed_url=NULL;
+    LinphoneCall *call;
     if (!linphone_core_interpret_url(lc,url,&real_url,&real_parsed_url)){
         /* bad url */
         return -1;
     }
-
-    LinphoneCall *call=lc->call;
+    call=lc->call;
     if (call==NULL){
         g_warning("No established call to refer.");
         return -1;
@@ -1319,7 +1325,7 @@ int linphone_core_change_qos(LinphoneCore *lc, int answer)
 	else
 	{
 		/* decline offer (603) */
-		linphone_core_terminate_dialog(lc, NULL);
+		linphone_core_terminate_call(lc, NULL);
 	}
 	return 0;
 }
@@ -1405,7 +1411,7 @@ void linphone_core_stop_media_streams(LinphoneCore *lc){
 #endif
 }
 
-int linphone_core_accept_dialog(LinphoneCore *lc, const char *url)
+int linphone_core_accept_call(LinphoneCore *lc, const char *url)
 {
 	char *sdpmesg;
 	
@@ -1430,7 +1436,7 @@ int linphone_core_accept_dialog(LinphoneCore *lc, const char *url)
 	return 0;
 }
 
-int linphone_core_terminate_dialog(LinphoneCore *lc, const char *url)
+int linphone_core_terminate_call(LinphoneCore *lc, const char *url)
 {
 	LinphoneCall *call=lc->call;
 	if (call==NULL){
@@ -1464,6 +1470,14 @@ int linphone_core_send_publish(LinphoneCore *lc,
 	return 0;
 }
 
+void linphone_core_set_inc_timeout(LinphoneCore *lc, int seconds){
+	lc->sip_conf.inc_timeout=seconds;
+}
+
+int linphone_core_get_inc_timeout(LinphoneCore *lc){
+	return lc->sip_conf.inc_timeout;
+}
+
 void linphone_core_set_presence_info(LinphoneCore *lc,gint minutes_away,
 													const gchar *contact,
 													LinphoneOnlineStatus presence_mode)
@@ -1721,30 +1735,53 @@ void linphone_core_force_ip_address(LinphoneCore *lc, const gchar *ipaddr)
 
 void linphone_core_set_nat_address(LinphoneCore *lc, const gchar *addr, gboolean use)
 {
+	gchar *wmsg;
 	gchar *tmp=NULL;
 	gint err;
 	struct addrinfo hints,*res;
 	
-	if (addr!=NULL && use){
-		memset(&hints,0,sizeof(struct addrinfo));
-		hints.ai_family=PF_UNSPEC;
-		hints.ai_socktype = SOCK_DGRAM;
-		err=getaddrinfo(addr,NULL,&hints,&res);
-		if (err==0){
-			tmp=g_strdup(addr);
+	if (addr!=NULL){
+		if (use){
+			/*check the ip address given */
+			memset(&hints,0,sizeof(struct addrinfo));
+			if (lc->sip_conf.ipv6_enabled)
+				hints.ai_family=AF_INET6;
+			else 
+				hints.ai_family=AF_INET;
+			hints.ai_socktype = SOCK_DGRAM;
+			err=getaddrinfo(addr,NULL,&hints,&res);
+			if (err!=0){
+				wmsg=g_strdup_printf(_("Invalid nat address '%s' : %s"),
+					addr, gai_strerror(err));
+				g_warning(wmsg); // what is this for ?
+				lc->vtable.display_warning(lc, wmsg);
+				g_free(wmsg);
+				return;
+			}
+			/*now get it as an numeric ip address */
+			tmp=g_malloc0(50);
+			err=getnameinfo(res->ai_addr,res->ai_addrlen,tmp,50,NULL,0,NI_NUMERICHOST);
+			if (err!=0){
+				wmsg=g_strdup_printf(_("Invalid nat address '%s' : %s"),
+					addr, gai_strerror(err));
+				g_warning(wmsg); // what is this for ?
+				lc->vtable.display_warning(lc, wmsg);
+				g_free(wmsg);
+				g_free(tmp);
+				freeaddrinfo(res);
+				return;
+			}
 			freeaddrinfo(res);
-		}else {
-			g_warning("Invalid nat address %s",addr);
-			return;
 		}
+		if (lc->net_conf.nat_address!=NULL){
+			g_free(lc->net_conf.nat_address);
+		}
+		lc->net_conf.nat_address=tmp;
 	}
-	if (lc->net_conf.nat_address!=NULL){
-		g_free(lc->net_conf.nat_address);
-	}
-	lc->net_conf.nat_address=tmp;
-	if (use && (tmp!=NULL)){
+
+	if (use && lc->net_conf.nat_address!=NULL) {
 		lc->net_conf.use_nat=TRUE;
-		eXosip_set_firewallip(tmp);
+		eXosip_set_firewallip(lc->net_conf.nat_address);
 	}
 	else {
 		lc->net_conf.use_nat=FALSE;
@@ -1837,6 +1874,7 @@ void sip_config_uninit(LinphoneCore *lc)
 	lp_config_set_int(lc->config,"sip","sip_port",config->sip_port);
 	lp_config_set_int(lc->config,"sip","guess_hostname",config->guess_hostname);
 	lp_config_set_string(lc->config,"sip","contact",config->contact);
+	lp_config_set_int(lc->config,"sip","inc_timeout",config->inc_timeout);
 	lp_config_set_int(lc->config,"sip","use_info",config->use_info);
 	lp_config_set_int(lc->config,"sip","use_ipv6",config->ipv6_enabled);
 	for(elem=config->proxies,i=0;elem!=NULL;elem=g_list_next(elem),i++){
@@ -1972,3 +2010,4 @@ void linphone_core_destroy(LinphoneCore *lc){
 	linphone_core_uninit(lc);
 	g_free(lc);
 }
+
