@@ -81,6 +81,7 @@ typedef struct sip_config
 	gint sip_port;
 	GList *proxies;
 	GList *deleted_proxies;
+	int inc_timeout;	/*timeout after an un-answered incoming call is rejected*/
 	gboolean use_info;
 	gboolean guess_hostname;
 	gboolean loopback_only;
@@ -426,9 +427,9 @@ typedef struct _LinphoneCore
 	struct _VideoStream *previewstream;
 	struct _RtpProfile *local_profile;
 	GList *subscribers;	/* unknown subscribers */
-	gint minutes_away;
+	int minutes_away;
 	LinphoneOnlineStatus	presence_mode;
-	gchar *alt_contact;
+	char *alt_contact;
 	int in_main_thread;
 	void *data;
 	GMutex *lock;
@@ -493,9 +494,9 @@ int linphone_core_change_qos(LinphoneCore *lc, int answer); /* answer = 1 for ye
 #endif
 gboolean linphone_core_inc_invite_pending(LinphoneCore*lc);
 
-int linphone_core_accept_dialog(LinphoneCore *lc, const char *url);
+int linphone_core_accept_call(LinphoneCore *lc, const char *url);
 
-int linphone_core_terminate_dialog(LinphoneCore *lc, const char *url);
+int linphone_core_terminate_call(LinphoneCore *lc, const char *url);
 
 void linphone_core_send_dtmf(LinphoneCore *lc,gchar dtmf);
 
@@ -516,6 +517,7 @@ void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *co
 GList *linphone_core_get_proxy_config_list(LinphoneCore *lc);
 
 void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *config);
+
 void linphone_core_set_default_proxy_index(LinphoneCore *lc, int index);
 
 int linphone_core_get_default_proxy(LinphoneCore *lc, LinphoneProxyConfig **config);
@@ -544,6 +546,11 @@ int linphone_core_get_sip_port(LinphoneCore *lc);
 
 void linphone_core_set_sip_port(LinphoneCore *lc,int port);
 
+void linphone_core_set_inc_timeout(LinphoneCore *lc, int seconds);
+
+int linphone_core_get_inc_timeout(LinphoneCore *lc);
+
+/* give a NULL addr to only set nat use */
 void linphone_core_set_nat_address(LinphoneCore *lc, const gchar *addr, gboolean use);
 
 const gchar *linphone_core_get_nat_address(LinphoneCore *lc, gboolean *use);
