@@ -35,6 +35,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <assert.h>
 
 #define lp_new0(type,n)	(type*)calloc(sizeof(type),n)
 
@@ -139,6 +140,14 @@ void lp_config_remove_section(LpConfig *lpconfig, LpSection *section){
 	lp_section_destroy(section);
 }
 
+static gboolean is_first_char(const char *start, const char *pos){
+	const char *p;
+	for(p=start;p<pos;p++){
+		if (*p!=' ') return FALSE;
+	}
+	return TRUE;
+}
+
 void lp_config_parse(LpConfig *lpconfig){
 	char tmp[MAX_LEN];
 	LpSection *cur=NULL;
@@ -148,17 +157,22 @@ void lp_config_parse(LpConfig *lpconfig){
 	while(fgets(tmp,MAX_LEN,lpconfig->file)!=NULL){
 		char *pos1,*pos2;
 		pos1=strchr(tmp,'[');
-		if (pos1!=NULL){
+		if (pos1!=NULL && is_first_char(tmp,pos1) ){
 			pos2=strchr(pos1,']');
 			if (pos2!=NULL){
+				int nbs;
 				char secname[MAX_LEN];
 				secname[0]='\0';
 				/* found section */
 				*pos2='\0';
-				sscanf(pos1+1,"%s",secname);
-				if (strlen(secname)>0){
-					cur=lp_section_new(secname);
-					lp_config_add_section(lpconfig,cur);
+				nbs = sscanf(pos1+1,"%s",secname);
+				if (nbs == 1 ){
+					if (strlen(secname)>0){
+						cur=lp_section_new(secname);
+						lp_config_add_section(lpconfig,cur);
+					}
+				}else{
+					g_warning("parse error!");
 				}
 			}
 		}else {
