@@ -58,7 +58,6 @@ int set_lock_file()
 /* looks if there is a lock file. If presents return its content (the pid of the already running linphone), if not found, returns -1*/
 int get_lock_file()
 {
-	
 	int pid;
 	FILE *lockfile;
 	
@@ -66,9 +65,13 @@ int get_lock_file()
 	lockfile=fopen(lock_name,"r");
 	if (lockfile==NULL)
 		return(-1);
-	fscanf(lockfile,"%i",&pid);
+	if (fscanf(lockfile,"%i",&pid)!=1){
+		g_warning("Could not read pid in lock file.");
+		fclose(lockfile);
+		return -1;
+	}
 	fclose(lockfile);
-	return(pid);
+	return pid;
 }
 
 /* remove the lock file if it was set*/
