@@ -20,6 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "linphonecore.h"
 #include <eXosip.h>
 #include <osipparser2/osip_message.h>
+#include "misc.h"
+#include "private.h"
 
 extern gint linphone_friend_set_contact(LinphoneFriend *lf, const gchar *contact);
 extern GList *find_friend(GList *fl, const gchar *friend, LinphoneFriend **lf);
@@ -27,7 +29,7 @@ extern const gchar *__policy_enum_to_str(LinphoneSubscribePolicy pol);
 
 int linphone_online_status_to_eXosip(LinphoneOnlineStatus os){
 	static int convtable[LINPHONE_STATUS_END];
-	static initialized=FALSE;
+	static gboolean initialized=FALSE;
 	if (!initialized){
 		convtable[LINPHONE_STATUS_AWAY]=EXOSIP_NOTIFY_AWAY;
 		convtable[LINPHONE_STATUS_UNKNOWN]=EXOSIP_NOTIFY_UNKNOWN;
