@@ -184,7 +184,7 @@ void linphone_proxy_config_done(LinphoneProxyConfig *obj)
 			osip_from_to_str(identity,&ct);
 			osip_from_free(identity);
 		}
-		obj->rid=eXosip_register_init((gchar*)id_str,obj->reg_proxy,ct);
+		obj->rid=eXosip_register_init((gchar*)id_str,obj->reg_proxy,ct,obj->reg_route);
 		linphone_proxy_config_register(obj);
 		if (ct!=NULL) g_free(ct);
 	}
