@@ -15,6 +15,7 @@
   * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   */
 
+
 #include "sdphandler.h"
 #include <osipparser2/osip_port.h>
 #include <osipparser2/sdp_message.h>
@@ -52,16 +53,18 @@ char *sdp_message_a_attr_value_get_with_pt(sdp_message_t *sdp,int pos,int pt,cha
 	sdp_attribute_t *attr;
 	for (i=0;(attr=sdp_message_attribute_get(sdp,pos,i))!=NULL;i++){
 		if (keywordcmp(field,attr->a_att_field)==0){
-			sscanf(attr->a_att_value,"%i %n",&tmppt,&scanned);
-			if (pt==tmppt){
-				tmp=attr->a_att_value+scanned;
-				if (strlen(tmp)>0)
-					return tmp;
-				else {
-					eXosip_trace(OSIP_WARNING,("sdp has a strange a= line."));
-					continue;
+			int nb = sscanf(attr->a_att_value,"%i %n",&tmppt,&scanned);
+			if (nb == 2 || nb==1 ){
+				if (pt==tmppt){
+					tmp=attr->a_att_value+scanned;
+					if (strlen(tmp)>0)
+						return tmp;
+					else {
+						eXosip_trace(OSIP_WARNING,("sdp has a strange a= line."));
+						continue;
+					}
 				}
-			}
+			}else eXosip_trace(OSIP_WARNING,("sdp has a strange a= line."));
 		}
 	}
 	return NULL;
