@@ -1040,6 +1040,40 @@ int eXosip_retry_call(int cid)
   return jc->c_id;
 }
 
+extern int cb_udp_snd_message(osip_transaction_t *tr, osip_message_t *sip,
+			      char *host, int port, int out_socket);
+
+int eXosip_send_ack(int did){
+	eXosip_call_t *call;
+	eXosip_dialog_t *dialog;
+	eXosip_call_dialog_find(did,&call,&dialog);
+	if (dialog!=NULL){
+		if (dialog->d_ack!=NULL){
+			osip_route_t *route;
+			int port;
+			char *host;
+			osip_message_t *ack=dialog->d_ack;
+			osip_message_get_route(ack, 0, &route);
+			if (route!=NULL)
+			{
+				port = 5060;
+				if (route->url->port!=NULL)
+				port = osip_atoi(route->url->port);
+				host = route->url->host;
+			}
+			else
+			{
+				port = 5060;
+				if (ack->req_uri->port!=NULL)
+				port = osip_atoi(ack->req_uri->port);
+				host = ack->req_uri->host;
+			}
+			
+			cb_udp_snd_message(NULL, ack, host, port, eXosip.j_socket);
+		}
+	}
+	return 0;
+}
 
 extern osip_list_t *supported_codec;
 
@@ -2441,7 +2475,12 @@ int eXosip_register      (int rid, int registration_period)
 	  return -2;
 	}
     }
-
+       //!jinti! if exist outbound proxy setting ,register must use outboundproxy!
+       if (jr->r_route!=NULL)
+       {
+         osip_message_set_route(reg, jr->r_route);
+       }
+	
   i = osip_transaction_init(&transaction,
 		       NICT,
 		       eXosip.j_osip,
@@ -2467,7 +2506,7 @@ int eXosip_register      (int rid, int registration_period)
 }
 
 int
-eXosip_register_init(char *from, char *proxy, char *contact)
+eXosip_register_init(char *from, char *proxy, char *contact, char *route)
 {
   eXosip_reg_t *jr;
   int i;
@@ -2483,7 +2522,7 @@ eXosip_register_init(char *from, char *proxy, char *contact)
     }
 
   /* Add new registration info */
-  i = eXosip_reg_init(&jr, from, proxy, contact);
+  i = eXosip_reg_init(&jr, from, proxy, contact, route);
   if (i!=0)
     {
       OSIP_TRACE (osip_trace
