@@ -164,7 +164,7 @@ void choose_address_and_close(GtkWidget *ab){
 		gtk_tree_model_get (model, &iter,SIP_ADDRESS_COLUMN , &address, -1);
 	}
 	if (address!=NULL){
-		gtk_entry_set_text (GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(addressentry))),address);
+		gtk_entry_set_text (GTK_ENTRY(addressentry),address);
 		g_free(address);
 	}
 	gtk_widget_destroy(ab);
