@@ -19,16 +19,10 @@
 #ifndef ADDRESSBOOK_H
 #define ADDRESSBOOK_H
 
-typedef struct _AddressBook
-{
-	LinphoneCore *lc;
-	GtkWidget *address_book;
-	GtkWidget *name_entry;
-	GtkWidget *address_entry;
-	GtkWidget *main_entry;
-	GtkWidget *address_list;
-} AddressBook;
+GtkWidget *create_and_fill_address_book();
+void show_address_book();
+GtkWidget * contact_new(LinphoneFriend *lf, GtkWidget *ab);
+GtkWidget * contact_edit(LinphoneFriend *lf, GtkWidget *ab);
+GtkWidget * subscriber_edit(LinphoneFriend *lf);
 
-void address_book_init(AddressBook *ab,LinphoneCore *lc,GtkWidget *main_entry);
-void address_book_uninit(AddressBook *ab, gboolean destroy_widget);
 #endif
