@@ -418,7 +418,7 @@ on_exit1_activate                      (GtkMenuItem     *menuitem,
 {
 #ifdef LINPHONE_APPLET
 #else	
-	gtk_main_quit();
+	gtk_widget_destroy(get_uiobj()->main_window.window);
 #endif
 }
 
@@ -517,17 +517,8 @@ on_call_logs_destroy                   (GtkObject       *object,
 	get_uiobj()->logs=NULL;
 }
 
-static gboolean accept_call_from_idle(LinphoneCore *lc){
-	linphone_core_accept_dialog(lc,NULL);
-	return FALSE;
-}
 
-static gboolean terminate_call_from_idle(LinphoneCore *lc){
-	linphone_core_terminate_dialog(lc,NULL);
-	return FALSE;	
-}
-
-static void completion_preprend_text_if_new(GtkEntry *entry, const char *text){
+static void completion_add_text(GtkEntry *entry, const char *text){
 	GtkTreeIter iter;
 	GtkTreeModel *model=gtk_entry_completion_get_model(gtk_entry_get_completion(entry));
 	
@@ -537,14 +528,17 @@ static void completion_preprend_text_if_new(GtkEntry *entry, const char *text){
 			gtk_tree_model_get(model,&iter,0,&uri,-1);
 			if (uri!=NULL){
 				if (strcmp(uri,text)==0) {
+					/*remove text */
+					gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
 					g_free(uri);
-					return;
+					break;
 				}
 				g_free(uri);
 			}
 		}while (gtk_tree_model_iter_next(model,&iter));
 	}
-	gtk_list_store_append(GTK_LIST_STORE(model),&iter);
+	/* and prepend it on top of the list */
+	gtk_list_store_prepend(GTK_LIST_STORE(model),&iter);
 	gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,text,-1);
 }
 
@@ -564,14 +558,9 @@ on_callbutton_clicked                  (GtkButton       *button,
 		/* get the url to call */
 		sipurl=gtk_entry_get_text(entry);
 		err=linphone_core_invite(lc,sipurl);
-		if (err==0) completion_preprend_text_if_new(entry,sipurl);
+		if (err==0) completion_add_text(entry,sipurl);
 	}else {
-		/* we cannot call linphone_core_accept_dialog() from this signal callback because
-		we are holding the gdk lock, which is needed also for the MSVideoOutput to finish.
-		This results in a deadlock.
-		As a workaround, we invoke linphone_core_accept_dialog() from the gtk idle loop.
-		*/
-		g_idle_add((GSourceFunc) accept_call_from_idle,(gpointer)lc);
+		linphone_core_accept_call(lc,NULL);
 	}
 }
 
@@ -584,7 +573,7 @@ on_hangup_clicked                      (GtkButton       *button,
 	if (lc->call!=NULL){
 		/* same trick here as for linphone_core_accept_dialog: defer it to gtk's idle loop */
 		gtk_window_set_title(GTK_WINDOW(ui->main_window.window),"linphone");
-		g_idle_add((GSourceFunc) terminate_call_from_idle,(gpointer)lc);
+		linphone_core_terminate_call(lc,NULL);
 	}
 }
 
