@@ -24,7 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "linphone.h"
 
 /* set audio levels on the main window*/
-void set_levels(LinphoneGnomeUI *ui,gint reclev, gint playlev);
+void set_levels(LinphoneGnomeUI *ui,gint reclev, gint playlev, gint ringlev);
 
 /* display an alternate url (used in 380 response) */
 void alt_ressource_display(LinphoneGnomeUI *ui, gchar *url);
