@@ -101,16 +101,8 @@ void net_selection_changed_cb(GtkTreeSelection *select, gpointer userdata)
 void net_section_fill(NetSection *sec,LinphoneCore *lc)
 {
 	gfloat value;
-	
-	GList *item_list,*elem;
-	GtkListStore *store ;
-	GtkTreeIter iter,selected;
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-	GtkTreeSelection *select;
 	gboolean use_nat;
-	gchar *tmp;
-	
+	const gchar *nat_address;
 	
 	value=(gfloat)linphone_core_get_audio_jittcomp(lc);
 	/* put the current value of jitt_comp*/
@@ -168,12 +160,11 @@ void net_section_fill(NetSection *sec,LinphoneCore *lc)
 #endif
 	
 	/* nat setup */
-	tmp=linphone_core_get_nat_address(lc,&use_nat);
+	nat_address=linphone_core_get_nat_address(lc,&use_nat);
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->enable_nat),use_nat);
-	if (tmp!=NULL) {
-		gtk_entry_set_text(GTK_ENTRY(sec->nat_address),tmp);
-		g_free(tmp);
+	if (nat_address!=NULL) {
+		gtk_entry_set_text(GTK_ENTRY(sec->nat_address),nat_address);
 	}
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->use_sipinfo),
 		linphone_core_get_use_info_for_dtmf(lc));
@@ -214,9 +205,6 @@ on_enable_ipv6_toggled                 (GtkToggleButton *togglebutton,
 
 void net_section_apply(NetSection *sec,LinphoneCore *lc)
 {
-	GtkTreeSelection *select;
-	GtkTreeIter iter;
-	GtkTreeModel *model;
 	gboolean use_nat;
 	gchar *name;
 #ifdef LINPHONE_DEPRECATED
@@ -265,7 +253,6 @@ void sip_section_init(SipSection *sec,GtkWidget *prop)
 {
 	
 	GtkListStore *store;
-	GtkTreeIter iter;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
@@ -308,8 +295,6 @@ void proxy_list_fill(GtkTreeModel *model, LinphoneCore *lc){
 void sip_section_fill(SipSection *sec, LinphoneCore *lc)
 {
 	osip_from_t *contact;
-	gchar *tmp;
-	gboolean  flag;
 	GtkTreeModel *model=gtk_tree_view_get_model(GTK_TREE_VIEW(sec->proxy_list));
 	
 	/* set sip port */
@@ -330,10 +315,8 @@ void sip_section_fill(SipSection *sec, LinphoneCore *lc)
 void sip_section_apply(SipSection *sec, LinphoneCore *lc)
 {
 	GtkAdjustment *adj;
-	gchar *tmp,*username,*hostname,*passwd;
-	gchar *regaddr,*addr_of_rec;
-	gint state,as_proxy=0,ind,err;
-	
+	gchar *tmp;
+	gchar *username,*hostname;
 	/* get sip port*/
 	adj=gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(sec->port));
 	
@@ -360,7 +343,6 @@ on_addproxy_button_clicked           (GtkButton       *button,
 {
 	GtkWidget *w=create_proxy_config_box();
 	gtk_widget_show(w);
-	printf("add proxy pressed\n");
 }
 
 
@@ -633,45 +615,61 @@ void codec_section_apply(CodecSection *sec, LinphoneCore *lc)
 
 void sound_section_init(SoundSection *sec, GtkWidget *prop)
 {
-	sec->card_entry=lookup_widget(prop,"card_entry");
-	sec->card_combo=lookup_widget(prop,"card_combo");
 	sec->source_entry=lookup_widget(prop,"rec_source");
 	sec->ringfileentry=lookup_widget(prop,"ringfileentry");
 }
 
+
 void
-on_card_changed                        (GtkEditable     *editable,
+on_play_card_changed                   (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-	gchar *tmp;
-	
-	/* get sound device*/
-	tmp=gtk_editable_get_chars(editable,0,-1);
-	if (strlen(tmp)>0) linphone_core_set_sound_device_from_name(get_core(),tmp);
-	g_free(tmp);
+	int dev=gtk_combo_box_get_active(combobox);
+	linphone_core_set_playback_device(get_core(),dev);
+	property_box_changed();
+}
+
+
+void
+on_capt_card_changed                   (GtkComboBox     *combobox,
+                                        gpointer         user_data)
+{
+	int dev=gtk_combo_box_get_active(combobox);
+	linphone_core_set_capture_device(get_core(),dev);
+	property_box_changed();
+}
+
+void
+on_ring_card_changed                   (GtkComboBox     *combobox,
+                                        gpointer         user_data)
+{
+	int dev=gtk_combo_box_get_active(combobox);
+	linphone_core_set_ringer_device(get_core(),dev);
+	property_box_changed();
 }
 
 void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
 {
-	gchar *dsppath;
-	int devid;
 	SndCardManager *cardmanager;
 	SndCard *card;
-	GList *cardlist=NULL;
+	GtkComboBox *play_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"play_card"));
+	GtkComboBox *capt_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"capt_card"));
+	GtkComboBox *ring_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"ring_card"));
 	int i;
 	/* select used sound drivers*/
 
-	devid=linphone_core_get_sound_device(lc);
 	cardmanager=linphone_core_get_card_manager(lc);
 	
 	for (i=0;(card=snd_card_manager_get_card(cardmanager,i))!=0;i++){
-		cardlist=g_list_append(cardlist,(gpointer)snd_card_get_identifier(card));
+		const gchar *carddesc=snd_card_get_identifier(card);
+		gtk_combo_box_append_text(play_card,carddesc);
+		gtk_combo_box_append_text(capt_card,carddesc);
+		gtk_combo_box_append_text(ring_card,carddesc);
 	}
-	gtk_combo_set_popdown_strings(GTK_COMBO(sec->card_combo),cardlist);
-	card=snd_card_manager_get_card(cardmanager,devid);
-	g_return_if_fail(card!=NULL);
-	gtk_entry_set_text (GTK_ENTRY (sec->card_entry),snd_card_get_identifier(card));
-	g_signal_connect(G_OBJECT(sec->card_entry),"changed",(GCallback)on_card_changed,NULL);
+	/*select used cards */
+	gtk_combo_box_set_active(play_card,linphone_core_get_playback_device(lc));
+	gtk_combo_box_set_active(capt_card,linphone_core_get_capture_device(lc));
+	gtk_combo_box_set_active(ring_card,linphone_core_get_ringer_device(lc));
 	/* select audio source*/
 	switch(linphone_core_get_sound_source(lc))
 	{
@@ -697,12 +695,6 @@ void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
 void sound_section_apply(SoundSection *sec, LinphoneCore *lc)
 {
 	gchar *tmp;
-	int devid;
-	
-	/* get sound device*/
-	tmp=gtk_editable_get_chars(GTK_EDITABLE(sec->card_entry),0,-1);
-	if (strlen(tmp)>0) linphone_core_set_sound_device_from_name(lc,tmp);
-	g_free(tmp);
 	
 	/* get audio source*/
 	tmp=gtk_editable_get_chars(GTK_EDITABLE(sec->source_entry),0,-1);
