@@ -71,8 +71,6 @@ void codec_section_apply(CodecSection *sec, LinphoneCore *lc);
 
 struct _SoundSection
 {
-	GtkWidget *card_combo;
-	GtkWidget *card_entry;
 	GtkWidget *source_entry;
 	GtkWidget *autokill_button;
 	GtkWidget *ringfileentry;
