@@ -36,9 +36,11 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
 	snd_pcm_hw_params_t *hwparams=NULL;
 	snd_pcm_sw_params_t *swparams=NULL;
 	snd_pcm_t *pcm_handle;
-	gint dir,exact_value;
+	gint dir;
+	guint exact_uvalue;
+	gulong exact_ulvalue;
 	gint channels;
-	gint fsize=0;
+//	gint fsize=0;
 	gint periods=8;
 	gint periodsize=256;
 	gint err;
@@ -81,15 +83,15 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
     }
 	/* Set sample rate. If the exact rate is not supported */
     /* by the hardware, use nearest possible rate.         */ 
-	exact_value=rate;
+	exact_uvalue=rate;
 	dir=0;
-    if ((err=snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &exact_value, &dir))<0){
+    if ((err=snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &exact_uvalue, &dir))<0){
 		g_warning("alsa_set_params: Error setting rate to %i:%s",rate,snd_strerror(err));
  		return -1;
 	}
     if (dir != 0) {
       g_warning("alsa_set_params: The rate %d Hz is not supported by your hardware.\n "
-		"==> Using %d Hz instead.\n", rate, exact_value);
+		"==> Using %d Hz instead.\n", rate, exact_uvalue);
     }
 	/* choose greater period size when rate is high */
 	periodsize=periodsize*(rate/8000);	
@@ -109,27 +111,27 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
     }
 	*/
 	/* set period size */
-	exact_value=periodsize;
+	exact_ulvalue=periodsize;
 	dir=0;
-    if (snd_pcm_hw_params_set_period_size_near(pcm_handle, hwparams, &exact_value, &dir) < 0) {
+    if (snd_pcm_hw_params_set_period_size_near(pcm_handle, hwparams, &exact_ulvalue, &dir) < 0) {
       g_warning("alsa_set_params: Error setting period size.\n");
       return(-1);
     }
 	if (dir != 0) {
       g_warning("alsa_set_params: The period size %d is not supported by your hardware.\n "
-		"==> Using %d instead.\n", periodsize, exact_value);
+		"==> Using %d instead.\n", periodsize, (int)exact_ulvalue);
     }
-	periodsize=exact_value;
+	periodsize=exact_ulvalue;
 	/* Set number of periods. Periods used to be called fragments. */ 
-	exact_value=periods;
+	exact_uvalue=periods;
 	dir=0;
-    if (snd_pcm_hw_params_set_periods_near(pcm_handle, hwparams, &exact_value, &dir) < 0) {
+    if (snd_pcm_hw_params_set_periods_near(pcm_handle, hwparams, &exact_uvalue, &dir) < 0) {
       g_warning("alsa_set_params: Error setting periods.\n");
       return(-1);
     }
 	if (dir != 0) {
       g_warning("alsa_set_params: The number of periods %d is not supported by your hardware.\n "
-		"==> Using %d instead.\n", periods, exact_value);
+		"==> Using %d instead.\n", periods, exact_uvalue);
     }
 	/* Apply HW parameter settings to */
     /* PCM device and prepare device  */
@@ -192,7 +194,8 @@ int alsa_card_open_r(AlsaCard *obj,int bits,int stereo,int rate)
 
 int alsa_card_open_w(AlsaCard *obj,int bits,int stereo,int rate)
 {
-	int err,bsize;
+//	int err;
+	int bsize;
 	snd_pcm_t *pcm_handle;
 	gchar *pcmdev;
 	if (over_pcmdev!=NULL) pcmdev=over_pcmdev;
@@ -266,7 +269,7 @@ gboolean alsa_card_can_read(AlsaCard *obj)
 	int frames;
 	g_return_val_if_fail(obj->read_handle!=NULL,0);
 	if (obj->readpos!=0) return TRUE;
-	if ( frames=snd_pcm_avail_update(obj->read_handle)>=obj->frames) return 1;
+	if ((frames=snd_pcm_avail_update(obj->read_handle)>=obj->frames)) return 1;
 	//g_message("frames=%i",frames);
 	return 0;
 }
@@ -336,22 +339,31 @@ int __alsa_card_write(AlsaCard *obj,char *buf,int size)
 	return err;
 }
 
-int alsa_card_write(AlsaCard *obj,char *buf,int size)
-{
+int alsa_card_write(AlsaCard *obj,char *buf,int size){
 	int err;
 	gint bsize=SND_CARD(obj)->bsize;
 	g_return_val_if_fail(obj->write_handle!=NULL,-1);
-	if (size<bsize){
+	if (size!=bsize || obj->writepos!=0)
+	{
 		gint canwrite;
+		gint totalwrite=0;
 		
-		canwrite=MIN(bsize-obj->writepos,size);
-		memcpy(&obj->writebuf[obj->writepos],buf,canwrite);
-		obj->writepos+=canwrite;
-		if (obj->writepos>=bsize){
-			err=__alsa_card_write(obj,obj->writebuf,bsize);
-			obj->writepos=0;
+		while(1){
+			canwrite=MIN(bsize-obj->writepos,size);
+			if (canwrite==0)
+				break;
+			memcpy(&obj->writebuf[obj->writepos],buf,canwrite);
+			obj->writepos+=canwrite;
+			if (obj->writepos>=bsize){
+				err=__alsa_card_write(obj,obj->writebuf,bsize);
+				obj->writepos=0;	
+			}
+			size-=canwrite;
+			buf+=canwrite;
+			totalwrite+=canwrite;
 		}
-		return canwrite;
+		return totalwrite;
+		
 	}else{
 		return __alsa_card_write(obj,buf,bsize);
 	}
@@ -429,6 +441,9 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 				break;
 				case CAPTURE_SWITCH:
 				
+				break;
+				case PLAYBACK_SWITCH:
+
 				break;
 			}
 		}
@@ -442,7 +457,6 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 static void set_mixer_element(snd_mixer_t *mixer,const char *name, gint level,MixerAction action){
 	const char *elemname;
 	snd_mixer_elem_t *elem;
-	int tmp;
 	long sndMixerPMin;
 	long sndMixerPMax;
 	long newvol;
@@ -518,7 +532,7 @@ void alsa_card_set_level(AlsaCard *obj,gint way,gint a)
 gint alsa_card_get_level(AlsaCard *obj,gint way)
 {
 	snd_mixer_t *mixer;
-	gint value;
+	gint value = -1;
 	mixer=alsa_mixer_open(obj);
 	if (mixer==NULL) return 0;
 	switch(way){
@@ -615,7 +629,6 @@ SndCard * alsa_card_new(gint devid)
 gint alsa_card_manager_init(SndCardManager *m, gint index)
 {
 	gint devindex;
-	gint i;
 	gint found=0;
 	gchar *name=NULL;
 	for(devindex=0;index<MAX_SND_CARDS && devindex<MAX_SND_CARDS ;devindex++){
@@ -630,7 +643,7 @@ gint alsa_card_manager_init(SndCardManager *m, gint index)
 	return found;
 }
 
-void alsa_card_manager_set_default_pcm_device(gchar *pcmdev){
+void alsa_card_manager_set_default_pcm_device(const gchar *pcmdev){
 	if (over_pcmdev!=NULL){
 		g_free(over_pcmdev);	
 	}
