@@ -88,7 +88,6 @@ const char *get_local_addr_for(const char *remote)
 {
 	const char *ret;
 #ifdef INET6
-	char num[8];
 	struct addrinfo hints, *res0;
 	int err;
 	memset(&hints, 0, sizeof(hints));
@@ -112,7 +111,7 @@ void create_duplex_rtpsession(RtpProfile *profile, int locport,char *remip,int r
 			RtpSession **recvsend){
 	RtpSession *rtpr;
 	rtpr=rtp_session_new(RTP_SESSION_SENDRECV);
-	rtp_session_max_buf_size_set(rtpr,MAX_RTP_SIZE);
+	rtp_session_set_recv_buf_size(rtpr,MAX_RTP_SIZE);
 	rtp_session_set_profile(rtpr,profile);
 	rtp_session_set_local_addr(rtpr,get_local_addr_for(remip),locport);
 	if (remport>0) rtp_session_set_remote_addr(rtpr,remip,remport);
@@ -129,11 +128,10 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip,int rempor
 				int payload,int jitt_comp,
 			RtpSession **recv, RtpSession **send){
 	RtpSession *rtps,*rtpr;
-	PayloadType *pt;
 	/* creates two rtp filters to recv send streams (remote part)*/
 	
 	rtps=rtp_session_new(RTP_SESSION_SENDONLY);
-	rtp_session_max_buf_size_set(rtps,MAX_RTP_SIZE);
+	rtp_session_set_recv_buf_size(rtps,MAX_RTP_SIZE);
 	rtp_session_set_profile(rtps,profile);
 #ifdef INET6
 	rtp_session_set_local_addr(rtps,"::",locport+2);
@@ -147,7 +145,7 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip,int rempor
 	rtp_session_set_jitter_compensation(rtps,jitt_comp);
 	
 	rtpr=rtp_session_new(RTP_SESSION_RECVONLY);
-	rtp_session_max_buf_size_set(rtpr,MAX_RTP_SIZE);
+	rtp_session_set_recv_buf_size(rtpr,MAX_RTP_SIZE);
 	rtp_session_set_profile(rtpr,profile);
 #ifdef INET6
 	rtp_session_set_local_addr(rtpr,"::",locport);
@@ -159,8 +157,7 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip,int rempor
 	rtp_session_set_send_payload_type(rtpr,payload);
 	rtp_session_set_recv_payload_type(rtpr,payload);
 	rtp_session_set_jitter_compensation(rtpr,jitt_comp);
-	rtp_session_signal_connect(rtpr,"telephone-event",(RtpCallback)on_dtmf_received,NULL);
-	rtp_session_signal_connect(rtpr,"timestamp_jump",(RtpCallback)on_timestamp_jump,NULL);
+	rtp_session_signal_connect(rtpr,"timestamp_jump",(RtpCallback)on_timestamp_jump,(unsigned long)NULL);
 	*recv=rtpr;
 	*send=rtps;
 	
@@ -177,7 +174,7 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *rem
 	//create_rtp_sessions(profile,locport,remip,remport,payload,jitt_comp,&rtpr,&rtps);
 	
 	create_duplex_rtpsession(profile,locport,remip,remport,payload,jitt_comp,&rtpr);
-	rtp_session_signal_connect(rtpr,"telephone-event",(RtpCallback)on_dtmf_received,(gpointer)stream);
+	rtp_session_signal_connect(rtpr,"telephone-event",(RtpCallback)on_dtmf_received,(unsigned long)stream);
 	rtps=rtpr;
 	
 	stream->rtpsend=ms_rtp_send_new();
@@ -216,8 +213,8 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *rem
 	ms_filter_set_property(stream->decoder,MS_FILTER_PROPERTY_FREQ,&pt->clock_rate);
 	ms_filter_set_property(stream->decoder,MS_FILTER_PROPERTY_BITRATE,&pt->normal_bitrate);
 	
-	ms_filter_set_property(stream->encoder,MS_FILTER_PROPERTY_FMTP, (void*)pt->fmtp);
-	ms_filter_set_property(stream->decoder,MS_FILTER_PROPERTY_FMTP,(void*)pt->fmtp);
+	ms_filter_set_property(stream->encoder,MS_FILTER_PROPERTY_FMTP, (void*)pt->send_fmtp);
+	ms_filter_set_property(stream->decoder,MS_FILTER_PROPERTY_FMTP,(void*)pt->recv_fmtp);
 	/* create the synchronisation source */
 	stream->timer=ms_timer_new();
 	
@@ -339,4 +336,5 @@ gint audio_stream_send_dtmf(AudioStream *stream, gchar dtmf)
 {
 	ms_rtp_send_dtmf(MS_RTP_SEND(stream->rtpsend), dtmf);
 	ms_oss_write_play_dtmf(MS_OSS_WRITE(stream->soundwrite),dtmf);
+	return 0;
 }
