@@ -38,6 +38,10 @@
 #include <dlfcn.h>
 #endif
 
+#ifdef HAVE_GLIB
+#include "gmodule.h"			/* g_module_open() */
+#endif
+
 #define MS_PLUGINS_DIR PACKAGE_PLUGINS_DIR "/mediastreamer"
 
 
@@ -383,6 +387,7 @@ void ms_load_plugins(const char *dir){
 			g_free(fullpath);
 		}
 	}
+	closedir(ds);
 #else
 	g_warning("no loadable plugin support: plugins cannot be loaded.");
 #endif
