@@ -21,7 +21,10 @@
 
 #ifndef MSBUFFER_H
 #define MSBUFFER_H
+
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #ifdef HAVE_GLIB
 #include <glib.h>
@@ -37,18 +40,19 @@ typedef struct _MSBuffer
 {
     gchar *buffer;
     guint32 size;
-    guint16 ref_count;
-    guint16 flags;
-#define MS_BUFFER_CONTIGUOUS (1)
+    gint ref_count;
+	void (*freefn)(void *);
+	void *freearg;
 }MSBuffer;
 
 MSBuffer * ms_buffer_new(guint32 size);
+MSBuffer *ms_buffer_new_with_buf(char *extbuf, int size,void (*freefn)(void *), void *freearg);
 void ms_buffer_destroy(MSBuffer *buf);
 
 struct _MSMessage
 {
 	MSBuffer *buffer; /* points to a MSBuffer */
-	void *data;          /*points to buffer->buffer  */
+	char *data;          /*points to buffer->buffer  */
 	guint32 size;   /* the size of the buffer to read in data. It may not be the
    								physical size (I mean buffer->buffer->size */
 	struct _MSMessage *next;
@@ -58,8 +62,6 @@ struct _MSMessage
 
 typedef struct _MSMessage MSMessage;
 
-
-MSBuffer *ms_buffer_alloc(gint flags);
 MSMessage *ms_message_new(gint size);
 
 #define ms_message_set_buf(m,b) do { (b)->ref_count++; (m)->buffer=(b); (m)->data=(b)->buffer; (m)->size=(b)->size; }while(0)
