@@ -54,7 +54,6 @@ MSFifo * ms_fifo_new_with_buffer(gint r_gran, gint w_gran, gint r_offset, gint w
 	MSBuffer *buf;
 	gint saved_offset=MAX(r_gran+r_offset,w_offset);
 	gint fifo_size;
-	gint tmp;
 	if (min_fifo_size==0) min_fifo_size=w_gran;
 	
 	/* we must allocate a fifo with a size multiple of min_fifo_size,
@@ -90,7 +89,7 @@ gint ms_fifo_get_read_ptr(MSFifo *fifo, gint bsize, void **ret_ptr)
 	if (bsize>fifo->readsize)
 	{
 		ms_trace("Not enough data: bsize=%i, readsize=%i",bsize,fifo->readsize);
-		return (-ENODATA);
+		return -1;
 	}
 	
 	rnext=fifo->rd_ptr+bsize;
@@ -137,7 +136,7 @@ gint ms_fifo_get_write_ptr(MSFifo *fifo, gint bsize, void **ret_ptr)
 	{
 		ms_trace("Not enough space: bsize=%i, writesize=%i",bsize,fifo->writesize);
 		*ret_ptr=NULL;
-		return(-ENODATA);
+		return -1;
 	}
 	wnext=fifo->wr_ptr+bsize;
 	if (wnext<=fifo->w_end){
