@@ -102,18 +102,17 @@ void ms_speex_dec_init(MSSpeexDec *obj)
 	
 }
 
-void ms_speex_dec_init_core(MSSpeexDec *obj,SpeexMode *mode)
+void ms_speex_dec_init_core(MSSpeexDec *obj,const SpeexMode *mode)
 {
 	int pf=1;
 	
-	obj->speex_state=speex_decoder_init(mode);
+	obj->speex_state=speex_decoder_init((SpeexMode*)mode);
 	speex_bits_init(&obj->bits);
 	/* enable the perceptual post filter */
 	speex_decoder_ctl(obj->speex_state,SPEEX_SET_PF, &pf);
 	
-	speex_mode_query(mode, SPEEX_MODE_FRAME_SIZE, &obj->frame_size);
+	speex_mode_query((SpeexMode*)mode, SPEEX_MODE_FRAME_SIZE, &obj->frame_size);
 	
-	obj->outbuf=g_malloc(sizeof(float)*obj->frame_size);
 	obj->initialized=1;
 }
 
@@ -128,13 +127,15 @@ int ms_speex_dec_set_property(MSSpeexDec *obj, MSFilterProperty prop, int *value
 		case MS_FILTER_PROPERTY_FREQ:
 			obj->frequency=value[0];
 		break;
+		default:
+		break;
 	}
 	return 0;
 }
 
 void ms_speex_dec_setup(MSSpeexDec *obj)
 {
-	SpeexMode *mode;
+	const SpeexMode *mode;
 	g_message("Speex decoder setup: freq=%i",obj->frequency);
 	if ( obj->frequency< 16000) mode=&speex_nb_mode;
 	else mode=&speex_wb_mode;
@@ -169,7 +170,7 @@ void ms_speex_dec_class_init(MSSpeexDecClass *klass)
 void ms_speex_dec_uninit_core(MSSpeexDec *obj)
 {
 	speex_decoder_destroy(obj->speex_state);
-	g_free(obj->outbuf);
+	speex_bits_destroy(&obj->bits);
 	obj->initialized=0;
 }
 
@@ -190,7 +191,6 @@ void ms_speex_dec_process(MSSpeexDec *obj)
 	MSQueue *inq=obj->inq[0];
 	gint16 *output;
 	gint gran=obj->frame_size*2;
-	gint i;
 	MSMessage *m;
 	
 	g_return_if_fail(inq!=NULL);
@@ -199,19 +199,17 @@ void ms_speex_dec_process(MSSpeexDec *obj)
 	m=ms_queue_get(inq);
 	g_return_if_fail(m!=NULL);
 	speex_bits_reset(&obj->bits);
+	ms_fifo_get_write_ptr(outf,gran,(void**)&output);
+	g_return_if_fail(output!=NULL);
 	if (m->data!=NULL){
 		
 		speex_bits_read_from(&obj->bits,m->data,m->size);
 		/* decode */
-		speex_decode(obj->speex_state,&obj->bits,obj->outbuf);
+		speex_decode_int(obj->speex_state,&obj->bits,(short*)output);
 	}else{
 		/* we have a missing packet */
-		speex_decode(obj->speex_state,NULL,obj->outbuf);
+		speex_decode_int(obj->speex_state,NULL,(short*)output);
 	}
 	ms_message_destroy(m);
 	
-	ms_fifo_get_write_ptr(outf,gran,(void**)&output);
-	g_return_if_fail(output!=NULL);
-	for (i=0;i<gran/2;i++) output[i]=obj->outbuf[i];
-	
 }
