@@ -21,7 +21,10 @@
 
 #include "msvideosource.h"
 #include "mediastream.h"
+
+#ifdef __linux
 #include "msv4l.h"
+#endif
 #ifdef HAVE_LIBDC1394
 #include "msdc1394.h"
 #endif
@@ -29,7 +32,9 @@
 /* register all statically linked codecs */
 void ms_video_source_register_all()
 {
+#ifdef __linux
 	ms_filter_register(&v4l_info);
+#endif
 #ifdef HAVE_LIBDC1394
 	ms_filter_register(MS_FILTER_INFO(&dc1394_info));
 #endif
@@ -82,6 +87,10 @@ void ms_video_source_set_frame_rate(MSVideoSource *f, gint frame_rate, gint fram
 {
 	if (MS_VIDEO_SOURCE_CLASS(MS_FILTER(f)->klass)->set_frame_rate)
 		MS_VIDEO_SOURCE_CLASS(MS_FILTER(f)->klass)->set_frame_rate(f, frame_rate, frame_rate_base);
+	else{
+		f->frame_rate=frame_rate;
+		f->frame_rate_base=frame_rate_base;
+	}
 }
 
 gchar* ms_video_source_get_format(MSVideoSource *f)
