@@ -32,7 +32,7 @@ void snd_card_uninit(SndCard *obj)
 	if (obj->card_name!=NULL) g_free(obj->card_name);
 }
 
-gchar *snd_card_get_identifier(SndCard *obj)
+const gchar *snd_card_get_identifier(SndCard *obj)
 {
 	return obj->card_name;
 }
@@ -40,13 +40,13 @@ gchar *snd_card_get_identifier(SndCard *obj)
 int snd_card_open_r(SndCard *obj, int bits, int stereo, int rate)
 {
 	g_return_val_if_fail(obj->_open_r!=NULL,-1);
-	g_message("Opening sound card in capture mode with stereo=%i,rate=%i,bits=%i",stereo,rate,bits);
+	g_message("Opening sound card [%s] in capture mode with stereo=%i,rate=%i,bits=%i",obj->card_name,stereo,rate,bits);
 	return obj->_open_r(obj,bits,stereo,rate);
 }
 int snd_card_open_w(SndCard *obj, int bits, int stereo, int rate)
 {
 	g_return_val_if_fail(obj->_open_w!=NULL,-1);
-	g_message("Opening sound card in playback mode with stereo=%i,rate=%i,bits=%i",stereo,rate,bits);
+	g_message("Opening sound card [%s] in playback mode with stereo=%i,rate=%i,bits=%i",obj->card_name,stereo,rate,bits);
 	return obj->_open_w(obj,bits,stereo,rate); 
 }
 
@@ -82,12 +82,14 @@ int snd_card_get_bsize(SndCard *obj)
 void snd_card_close_r(SndCard *obj)
 {
 	g_return_if_fail(obj->_close_r!=NULL);
+	g_message("Closing reading channel of soundcard.");
 	obj->_close_r(obj);
 }
 
 void snd_card_close_w(SndCard *obj)
 {
 	g_return_if_fail(obj->_close_w!=NULL);
+	g_message("Closing writing channel of soundcard.");
 	obj->_close_w(obj);
 }
 
@@ -141,6 +143,12 @@ gint sys_audio_manager_init(SndCardManager *manager, gint index)
 
 #include "osscard.h"
 #include "alsacard.h"
+#include "jackcard.h"
+
+#ifdef HAVE_SYS_SOUNDCARD_H
+/* in osscard.c */
+gint oss_card_manager_init(SndCardManager *manager, gint tabindex);
+#endif
 
 void snd_card_manager_init(SndCardManager *manager)
 {
@@ -157,6 +165,11 @@ void snd_card_manager_init(SndCardManager *manager)
 	index+=tmp;
 	if (index>=MAX_SND_CARDS) return;
 	#endif
+	#ifdef __JACK_ENABLED__
+	tmp=jack_card_manager_init(manager,index);
+	index+=tmp;
+	if (index>=MAX_SND_CARDS) return;
+	#endif
 	#ifdef HAVE_SYS_AUDIO_H
 	tmp=sys_audio_manager_init(manager,index);
 	index+=tmp;
@@ -175,7 +188,7 @@ SndCard * snd_card_manager_get_card(SndCardManager *manager,int index)
 	return manager->cards[index];	
 }
 
-SndCard * snd_card_manager_get_card_with_string(SndCardManager *manager,char *cardname,int *index)
+SndCard * snd_card_manager_get_card_with_string(SndCardManager *manager,const char *cardname,int *index)
 {
 	int i;
 	for (i=0;i<MAX_SND_CARDS;i++){
@@ -183,7 +196,7 @@ SndCard * snd_card_manager_get_card_with_string(SndCardManager *manager,char *ca
 		if (manager->cards[i]==NULL) continue;
 		card_name=manager->cards[i]->card_name;
 		if (card_name==NULL) continue;
-		if (strncmp(card_name,cardname,strlen(card_name))==0){
+		if (strcmp(card_name,cardname)==0){
 			*index=i;
 			return manager->cards[i];
 		}
