@@ -2,6 +2,6 @@ set -x
 rm -rf config.cache autom4te.cache
 aclocal
 autoheader
-automake --force-missing --add-missing --copy
+automake --add-missing --copy
 libtoolize --copy --force
 autoconf
