@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 
 #ifndef PAYLOADTYPE_H
 #define PAYLOADTYPE_H
-#include <ortp/rtpport.h>
+#include <ortp/port.h>
 
 /* flags for PayloadType::flags */
 
@@ -36,19 +36,20 @@
 
 struct _PayloadType
 {
-	gint type;
+	int type;
 	#define PAYLOAD_AUDIO_CONTINUOUS 0
 	#define PAYLOAD_AUDIO_PACKETIZED 1
 	#define	PAYLOAD_VIDEO 2
 	#define PAYLOAD_OTHER 3  /* ?? */
-	gint clock_rate;
+	int clock_rate;
 	char bits_per_sample;		/* in case of continuous audio data */
 	char *zero_pattern;
-	gint pattern_length;
-	/* other usefull information */
-	gint normal_bitrate;	/*in bit/s */
+	int pattern_length;
+	/* other useful information for the application*/
+	int normal_bitrate;	/*in bit/s */
 	char *mime_type;
-	char *fmtp;	/*various parameters, as a string */
+	char *recv_fmtp; /* various format parameters for the incoming stream */
+	char *send_fmtp; /* various format parameters for the outgoing stream */
 	int flags;
 	void *user_data;
 };
@@ -58,16 +59,6 @@ struct _PayloadType
 typedef struct _PayloadType PayloadType;
 #endif
 
-#ifdef __cplusplus
-extern "C"{
-#endif
-PayloadType *payload_type_new();
-PayloadType *payload_type_clone(PayloadType *payload);
-void payload_type_destroy(PayloadType *pt);
-#ifdef __cplusplus
-}
-#endif
-
 #define payload_type_set_flag(pt,flag) (pt)->flags|=((int)flag)
 #define payload_type_unset_flag(pt,flag) (pt)->flags&=(~(int)flag)
 
@@ -82,36 +73,58 @@ struct _RtpProfile
 
 typedef struct _RtpProfile RtpProfile;
 
+#ifdef __cplusplus
+extern "C"{
+#endif
+PayloadType *payload_type_new();
+PayloadType *payload_type_clone(PayloadType *payload);
+void payload_type_destroy(PayloadType *pt);
+void payload_type_set_recv_fmtp(PayloadType *pt, const char *fmtp);
+void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 
 extern RtpProfile av_profile;
 
+#ifdef __cplusplus
+}
+#endif
+
+
 #define payload_type_set_user_data(pt,p)	(pt)->user_data=(p)
 #define payload_type_get_user_data(pt)		((pt)->user_data)
 
 
 
 #define rtp_profile_get_name(profile) 	(const char*)((profile)->name)
-#define rtp_profile_set_payload(profile,index,pt)  (profile)->payload[(index)]=(pt)
-#define rtp_profile_clear_payload(profile,index)	(profile)->payload[(index)]=NULL
-#define rtp_profile_clear_all(profile)	memset((void*)(profile),0,sizeof(RtpProfile))
-#define rtp_profile_get_payload(profile,index)	((profile)->payload[(index)])
+
 #ifdef __cplusplus
 extern "C"{
 #endif
+
+void rtp_profile_set_payload(RtpProfile *prof, int index, PayloadType *pt);
+
+#define rtp_profile_clear_payload(profile,index)	rtp_profile_set_payload(profile,index,NULL)	
+
+/* I prefer have this function inlined because it is very often called in the code */
+static inline PayloadType * rtp_profile_get_payload(RtpProfile *prof, int index){
+	if (index<0 || index>=RTP_PROFILE_MAX_PAYLOADS) {
+		return NULL;
+	}
+	return prof->payload[index];
+}
+void rtp_profile_clear_all(RtpProfile *prof);
 void rtp_profile_set_name(RtpProfile *prof, const char *name);
 PayloadType * rtp_profile_get_payload_from_mime(RtpProfile *profile,const char *mime);
 PayloadType * rtp_profile_get_payload_from_rtpmap(RtpProfile *profile, const char *rtpmap);
-gint rtp_profile_get_payload_number_from_mime(RtpProfile *profile,const char *mime);
-gint rtp_profile_get_payload_number_from_rtpmap(RtpProfile *profile, const char *rtpmap);
-gint rtp_profile_find_payload_number(RtpProfile *prof,const gchar *mime,int rate);
-PayloadType * rtp_profile_find_payload(RtpProfile *prof,const gchar *mime,int rate);
-gint rtp_profile_move_payload(RtpProfile *prof,int oldpos,int newpos);
+int rtp_profile_get_payload_number_from_mime(RtpProfile *profile,const char *mime);
+int rtp_profile_get_payload_number_from_rtpmap(RtpProfile *profile, const char *rtpmap);
+int rtp_profile_find_payload_number(RtpProfile *prof,const char *mime,int rate);
+PayloadType * rtp_profile_find_payload(RtpProfile *prof,const char *mime,int rate);
+int rtp_profile_move_payload(RtpProfile *prof,int oldpos,int newpos);
 
 RtpProfile * rtp_profile_new(const char *name);
 /* clone a profile, payload are not cloned */
 RtpProfile * rtp_profile_clone(RtpProfile *prof);
-/* copy a profile into another one; payload are not cloned */
-void rtp_profile_copy(const RtpProfile *orig, RtpProfile *dest);
+
 
 /*clone a profile and its payloads (ie payload type are newly allocated, not reusing payload types of the reference profile) */
 RtpProfile * rtp_profile_clone_full(RtpProfile *prof);
