@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
 #ifndef RTCP_H
 #define RTCP_H
 
-#include <ortp/rtpport.h>
+#include <ortp/port.h>
 
 #define RTCP_MAX_RECV_BUFSIZE 1024
 
@@ -44,18 +44,18 @@ typedef enum {
  
 typedef struct rtcp_common_header
 {
-#ifdef WORDS_BIGENDIAN
-        guint16 version:2;
-        guint16 padbit:1;
-        guint16 rc:5;
-        guint16 packet_type:8;
+#ifdef ORTP_BIGENDIAN
+        uint16_t version:2;
+        uint16_t padbit:1;
+        uint16_t rc:5;
+        uint16_t packet_type:8;
 #else
-        guint16 rc:5;
-        guint16 padbit:1;
-        guint16 version:2;
-		guint16 packet_type:8;
+        uint16_t rc:5;
+        uint16_t padbit:1;
+        uint16_t version:2;
+		uint16_t packet_type:8;
 #endif
-        guint16 length:16;
+        uint16_t length:16;
 } rtcp_common_header_t;
 
 #define rtcp_common_header_set_version(ch,v) (ch)->version=v
@@ -75,22 +75,22 @@ typedef struct rtcp_common_header
 
 typedef struct sender_info
 {
-        guint32 ntp_timestamp_msw;
-        guint32 ntp_timestamp_lsw;
-        guint32 rtp_timestamp;
-        guint32 senders_packet_count;
-        guint32 senders_octet_count;
+        uint32_t ntp_timestamp_msw;
+        uint32_t ntp_timestamp_lsw;
+        uint32_t rtp_timestamp;
+        uint32_t senders_packet_count;
+        uint32_t senders_octet_count;
 } sender_info_t;
  
 typedef struct report_block
 {
-        guint32 ssrc;
-        guint32 fraction_lost:8;
-        guint32 cum_num_packet_lost:24; /*cumulative number of packet lost*/
-        guint32 ext_high_seq_num_rec; /*extended highest sequence number received */
-        guint32 interarrival_jitter;
-        guint32 lsr; /*last SR */
-        guint32 delay_snc_last_sr; /*delay since last sr*/
+        uint32_t ssrc;
+        uint32_t fraction_lost:8;
+        uint32_t cum_num_packet_lost:24; /*cumulative number of packet lost*/
+        uint32_t ext_high_seq_num_rec; /*extended highest sequence number received */
+        uint32_t interarrival_jitter;
+        uint32_t lsr; /*last SR */
+        uint32_t delay_snc_last_sr; /*delay since last sr*/
 } report_block_t;
 
 
@@ -111,14 +111,14 @@ typedef enum {
 
 typedef struct sdes_chunk
 {
-	guint32 csrc;
+	uint32_t csrc;
 } sdes_chunk_t;
 
 typedef struct sdes_item
 {
-	guint8 item_type;
-    guint8 len;
-	gchar content[1];	
+	uint8_t item_type;
+	uint8_t len;
+	char content[1];	
 } sdes_item_t;
 
 #define RTCP_SDES_MAX_STRING_SIZE 255
@@ -130,14 +130,14 @@ typedef struct sdes_item
 
 typedef struct rtcp_bye_reason
 {
-    guint8 len;
-	gchar content[1];
+	uint8_t len;
+	char content[1];
 } rtcp_bye_reason_t;
  
 typedef struct rtcp_bye
 {
 	rtcp_common_header_t ch;
-	guint32 ssrc[1];  /* the bye may contain several ssrc/csrc */
+	uint32_t ssrc[1];  /* the bye may contain several ssrc/csrc */
 } rtcp_bye_t;
 #define RTCP_BYE_HEADER_SIZE sizeof(rtcp_bye_t)
 #define RTCP_BYE_REASON_MAX_STRING_SIZE 255
@@ -148,14 +148,14 @@ typedef struct rtcp_bye
 
 typedef struct rtcp_sr{
 	rtcp_common_header_t ch;
-	guint32 ssrc;
+	uint32_t ssrc;
 	sender_info_t si;
 	report_block_t rb[1];
 } rtcp_sr_t;
 
 typedef struct rtcp_rr{
 	rtcp_common_header_t ch;
-	guint32 ssrc;
+	uint32_t ssrc;
 	report_block_t rb[1];
 } rtcp_rr_t;
 
