@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -26,18 +26,18 @@
 
 struct _telephone_event
 {
-#ifdef WORDS_BIGENDIAN
-	guint32 event:8;
-	guint32 E:1;
-	guint32 R:1;
-	guint32 volume:6;
-	guint32 duration:16;
+#ifdef ORTP_BIGENDIAN
+	uint32_t event:8;
+	uint32_t E:1;
+	uint32_t R:1;
+	uint32_t volume:6;
+	uint32_t duration:16;
 #else
-	guint32 event:8;
-	guint32 volume:6;
-	guint32 R:1;
-	guint32 E:1;
-	guint32 duration:16;
+	uint32_t event:8;
+	uint32_t volume:6;
+	uint32_t R:1;
+	uint32_t E:1;
+	uint32_t duration:16;
 #endif
 };
 
@@ -53,18 +53,18 @@ extern PayloadType	payload_type_telephone_event;
 	must be present in the rtp profile used by the session */
 	
 /* low level functions */	
-gint rtp_session_telephone_events_supported(RtpSession *session);
+int rtp_session_telephone_events_supported(RtpSession *session);
 
 mblk_t	*rtp_session_create_telephone_event_packet(RtpSession *session, int start);
 
-gint rtp_session_add_telephone_event(RtpSession *session,
-			mblk_t *packet, guchar event, gint end, guchar volume, guint16 duration);
+int rtp_session_add_telephone_event(RtpSession *session,
+			mblk_t *packet, uint8_t event, int end, uint8_t volume, uint16_t duration);
 			
-gint rtp_session_read_telephone_event(RtpSession *session,
+int rtp_session_read_telephone_event(RtpSession *session,
 		mblk_t *packet,telephone_event_t **tab);
 
 /* high level functions*/
-gint rtp_session_send_dtmf(RtpSession *session, gchar dtmf, guint32 userts);
+int rtp_session_send_dtmf(RtpSession *session, char dtmf, uint32_t userts);
 /* for high level telephony event callback */
 void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0);
 
