@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -17,27 +17,21 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <ortp/ortp.h>
+
+#include "ortp/ortp.h"
+#include "ortp-config.h"
 #include "scheduler.h"
-#include <stdlib.h>
 
 rtp_stats_t ortp_global_stats;
 
 #ifdef ENABLE_MEMCHECK
-gint ortp_allocations=0;
+int ortp_allocations=0;
 #endif
 
 
 RtpScheduler *__ortp_scheduler;
 
 
-void dummy_log(const gchar *log_domain,
-                                             GLogLevelFlags log_level,
-                                             const gchar *message,
-                                             gpointer user_data)
-{
-	return;
-}
 
 extern void av_profile_init(RtpProfile *profile);
 
@@ -56,29 +50,14 @@ static void init_random_number_generator(){
  
 void ortp_init()
 {
-	static gboolean initialized=FALSE;
+	static bool_t initialized=FALSE;
 	if (initialized) return;
 	initialized=TRUE;
 
-#ifdef _WIN32
-	WORD wVersionRequested;
-	WSADATA wsaData;
- 
-	wVersionRequested = MAKEWORD( 1, 0 );
-
-	if (WSAStartup(wVersionRequested,&wsaData)!=0) 
-	{
-		g_error("Fail to initialise socket api");
-	}
-#endif
-
-#ifdef HAVE_GLIB
-	if (!g_thread_supported()) g_thread_init (NULL);
-#endif
 	av_profile_init(&av_profile);
 	ortp_global_stats_reset();
 	init_random_number_generator();
-	g_message("oRTP-" ORTP_VERSION "initialized.");
+	ortp_message("oRTP-" ORTP_VERSION " initialized.");
 }
 
 
@@ -91,7 +70,7 @@ void ortp_init()
 **/
 void ortp_scheduler_init()
 {
-	static gboolean initialized=FALSE;
+	static bool_t initialized=FALSE;
 	if (initialized) return;
 	initialized=TRUE;
 #ifdef __hpux
@@ -103,7 +82,7 @@ void ortp_scheduler_init()
 	sigaddset(&set,SIGALRM);
 	sigprocmask(SIG_BLOCK,&set,NULL);
 #endif /* __hpux */
-	if (!g_thread_supported()) g_thread_init(NULL);
+
 	__ortp_scheduler=rtp_scheduler_new();
 	rtp_scheduler_start(__ortp_scheduler);
 	//sleep(1);
@@ -135,61 +114,113 @@ void ortp_exit()
 **/
 RtpScheduler * ortp_get_scheduler()
 {
-	if (__ortp_scheduler==NULL) g_error("Cannot use the scheduled mode: the scheduler is not "
+	if (__ortp_scheduler==NULL) ortp_error("Cannot use the scheduled mode: the scheduler is not "
 									"started. Call ortp_scheduler_init() at the begginning of the application.");
 	return __ortp_scheduler;
 }
 
 
-void ortp_log(const gchar *log_domain,GLogLevelFlags log_level,
-                                           const gchar *message,
-                                           gpointer user_data)
-{
-	gchar *lev;
-	switch(log_level){
-		case G_LOG_LEVEL_MESSAGE:
-			lev="message";
-			break;
-		case G_LOG_LEVEL_WARNING:
-			lev="warning";
-			break;
-		case G_LOG_LEVEL_ERROR:
-			lev="error";
-		default:
-			lev="(unknown log type)";
-	}
-	if (user_data==NULL){
-		user_data=stdout;
-	}
-	fprintf((FILE*)user_data,"%s-%s:%s\n",log_domain,lev,message);
-}
-
+static FILE *__log_file=0;
 
 /**
- *ortp_set_debug_file:
- *@domain:	one of "oRTP" or "oRTP-stats" logging domain.
- *@file: a FILE pointer where to output the messages from the domain.
+ *ortp_set_log_file:
+ *@file: a FILE pointer where to output the ortp logs.
  *
- * Warning: domain is ignored when not compiling with glib support.
 **/
-void ortp_set_debug_file(gchar *domain,FILE *file)
+void ortp_set_log_file(FILE *file)
 {
-	if (file!=NULL)
-		g_log_set_handler (domain, G_LOG_LEVEL_MASK, ortp_log, (gpointer)file);
-	else g_log_set_handler (domain, G_LOG_LEVEL_MASK, dummy_log, NULL);
+	__log_file=file;
 }
+
+static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args);
+
+OrtpLogFunc ortp_logv_out=__ortp_logv_out;
+
 /**
  *ortp_set_log_handler:
- *@domain: one of the "oRTP" or "oRTP-stats" logging domain.
- *@func: your logging function, compatible with the GLogFunc prototype.
+ *@func: your logging function, compatible with the OrtpLogFunc prototype.
  *
- * Warning: domain is ignored when not compiling with glib support.
 **/
-void ortp_set_log_handler(const gchar *domain, GLogFunc func, gpointer userdata){
-	g_log_set_handler(domain,G_LOG_LEVEL_MASK,func,userdata);
+void ortp_set_log_handler(OrtpLogFunc func){
+	ortp_logv_out=func;
 }
 
 
+unsigned int __ortp_log_mask=ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL;
+
+void ortp_set_log_level_mask(int levelmask){
+	__ortp_log_mask=levelmask;
+}
+
+static char * _strdup_vprintf(const char *fmt, va_list ap)
+{
+	/* Guess we need no more than 100 bytes. */
+	int n, size = 100;
+	char *p;
+	if ((p = (char *) ortp_malloc (size)) == NULL)
+		return NULL;
+	while (1)
+	{
+		/* Try to print in the allocated space. */
+		n = vsnprintf (p, size, fmt, ap);
+		/* If that worked, return the string. */
+		if (n > -1 && n < size)
+			return p;
+		//printf("Reallocing space.\n");
+		/* Else try again with more space. */
+		if (n > -1)	/* glibc 2.1 */
+			size = n + 1;	/* precisely what is needed */
+		else		/* glibc 2.0 */
+			size *= 2;	/* twice the old size */
+		if ((p = (char *) ortp_realloc (p, size)) == NULL)
+			return NULL;
+	}
+}
+
+char *ortp_strdup_printf(const char *fmt,...){
+	char *ret;
+	va_list args;
+	va_start (args, fmt);
+	ret=_strdup_vprintf(fmt, args);
+ 	va_end (args);
+	return ret;
+}
+
+#ifdef _WIN32
+#define ENDLINE "\r\n"
+#else
+#define ENDLINE "\n"
+#endif
+
+
+static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args){
+	const char *lname="undef";
+	char *msg;
+	if (__log_file==NULL) __log_file=stderr;
+	switch(lev){
+		case ORTP_DEBUG:
+			lname="debug";
+			break;
+		case ORTP_MESSAGE:
+			lname="message";
+			break;
+		case ORTP_WARNING:
+			lname="warning";
+			break;
+		case ORTP_ERROR:
+			lname="error";
+			break;
+		case ORTP_FATAL:
+			lname="fatal";
+			break;
+		default:
+			ortp_fatal("Bad level !");
+	}
+	msg=_strdup_vprintf(fmt,args);
+	fprintf(__log_file,"ortp-%s-%s" ENDLINE,lname,msg);
+	ortp_free(msg);
+}
+
 
 void ortp_global_stats_display()
 {
@@ -200,11 +231,11 @@ void ortp_global_stats_display()
 }
 
 
-void rtp_stats_display(rtp_stats_t *stats, char *header)
+void rtp_stats_display(rtp_stats_t *stats, const char *header)
 {
 
-	g_log("oRTP-stats",G_LOG_LEVEL_MESSAGE,
-			"\n   %s :\n"
+	ortp_log(ORTP_MESSAGE,
+			"oRTP-stats:\n   %s :\n"
 	      " number of rtp packet sent=%lld\n"
 	      " number of rtp bytes sent=%lld bytes\n"
 	      " number of rtp packet received=%lld\n"
@@ -252,7 +283,7 @@ void rtp_stats_reset(rtp_stats_t *stats){
  *
  * Returns: true if ortp has a version number greater or equal than the required one.
 **/
-gboolean ortp_min_version_required(int major, int minor, int micro){
+bool_t ortp_min_version_required(int major, int minor, int micro){
 	return ((major*1000000) + (minor*1000) + micro) <= 
 		   ((ORTP_MAJOR_VERSION*1000000) + (ORTP_MINOR_VERSION*1000) + ORTP_MICRO_VERSION);
 }
