@@ -17,9 +17,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <ortp/rtpport.h>
+#include "ortp/ortp.h"
 #include "rtptimer.h"
-
+#include "ortp-config.h"
 
 #ifndef _WIN32
 
@@ -33,7 +33,7 @@
 
 
 static struct timeval orig,cur;
-static guint32 posix_timer_time=0;		/*in milisecond */
+static uint32_t posix_timer_time=0;		/*in milisecond */
 
 void posix_timer_init()
 {
@@ -47,13 +47,12 @@ void posix_timer_init()
 
 void posix_timer_do()
 {
-	gint32 diff,time;
+	int diff,time;
 	struct timeval tv;
-
 	gettimeofday(&cur,NULL);
 	time=((cur.tv_usec-orig.tv_usec)/1000 ) + ((cur.tv_sec-orig.tv_sec)*1000 );
 	if ( (diff=time-posix_timer_time)>50){
-		g_warning("Must catchup %i miliseconds.",diff);
+		ortp_warning("Must catchup %i miliseconds.",diff);
 	}
 	while((diff = posix_timer_time-time) > 0)
 	{
@@ -81,6 +80,7 @@ RtpTimer posix_timer={	0,
 							
 #else //WIN32
 
+
 #include <windows.h>
 #include <mmsystem.h>
 
@@ -141,7 +141,7 @@ void win_timer_do(void)
         if( diff>TIME_INTERVAL && (diff<(1<<31)))
         {
                 late_ticks = diff/TIME_INTERVAL;
-                g_warning("we must catchup %i ticks.",late_ticks);
+                ortp_warning("we must catchup %i ticks.",late_ticks);
                 return;
         }
 
