@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This source code file was written by Nicola Baldo as an extension of 
@@ -21,8 +21,8 @@
 */
 
 
-#include <ortp/ortp.h>
-
+#include "ortp/ortp.h"
+#include "utils.h"
 
 
 void report_block_parse(RtpSession *session, report_block_t *rb, struct timeval rcv_time_tv)
@@ -39,13 +39,13 @@ void report_block_parse(RtpSession *session, report_block_t *rb, struct timeval
   else
 
     {
-      guint32 rcv_time_msw;	   
-      guint32 rcv_time_lsw;
-      guint32 rcv_time;
+      uint32_t rcv_time_msw;	   
+      uint32_t rcv_time_lsw;
+      uint32_t rcv_time;
       double rtt;
 
       rcv_time_msw = rcv_time_tv.tv_sec;
-      rcv_time_lsw = (guint32) ((double)rcv_time_tv.tv_usec*(double)(1LL<<32)*1.0e-6);
+      rcv_time_lsw = (uint32_t) ((double)rcv_time_tv.tv_usec*(double)(1LL<<32)*1.0e-6);
       rcv_time = (rcv_time_msw<<16) | (rcv_time_lsw >> 16);
 
       rb->cum_num_packet_lost = ntoh24(rb->cum_num_packet_lost);
@@ -67,7 +67,6 @@ void report_block_parse(RtpSession *session, report_block_t *rb, struct timeval
 
 }
 
-
 void rtcp_parse(RtpSession *session, mblk_t *mp)
 {
   rtcp_common_header_t *rtcp;
@@ -78,12 +77,10 @@ void rtcp_parse(RtpSession *session, mblk_t *mp)
 
   
   gettimeofday(&rcv_time_tv,NULL);
-	
-  g_return_if_fail(mp!=NULL);
-	
-  msgsize=mp->b_wptr-mp->b_rptr;
 
- 
+  return_if_fail(mp!=NULL);
+
+  msgsize=(int) (mp->b_wptr-mp->b_rptr);
 
   if (msgsize < RTCP_COMMON_HEADER_SIZE)
     {
@@ -93,21 +90,27 @@ void rtcp_parse(RtpSession *session, mblk_t *mp)
 
   rtcp=(rtcp_common_header_t *)mp->b_rptr;
 
-
   /* compound rtcp packet can be composed by more than one rtcp message */
   while (msgsize >= RTCP_COMMON_HEADER_SIZE)
-
-    {      
+    {
 
       if (rtcp->version!=2)
-	{
-	  ortp_debug("Receiving rtcp packet with version number !=2...discarded");
-	  return;
-	}
-	
+        {
+          ortp_debug("Receiving rtcp packet with version number !=2...discarded");
+          return;
+        }
+
       /* convert header data from network order to host order */
       rtcp->length = ntohs(rtcp->length);
 
+      /* compute length */
+      rtcp_pk_size = (rtcp->length + 1) * 4;
+      /* Sanity check of simple RTCP packet length. */
+      if (rtcp_pk_size > msgsize)
+        {
+          ortp_debug("Receiving rtcp packet shorter than the specified length.. discared");
+          return;
+        }
 
       switch (rtcp->packet_type)   
 
@@ -164,11 +167,16 @@ void rtcp_parse(RtpSession *session, mblk_t *mp)
 	    report_block_t *rb;
 	    int i;
 
-	    if ( ntohl(rr->ssrc) != session->recv_ssrc )
-	      {
-		ortp_debug("Receiving rtcp rr packet from unknown ssrc.. discarded");
-		return;
-	      }
+        if (session->recv_ssrc == 0)
+          {
+            /* recv_ssrc is not set, so we adopt the incoming one */
+            session->recv_ssrc = ntohl(rr->ssrc);
+          }
+	    else if ( ntohl(rr->ssrc) != session->recv_ssrc )
+          {
+            ortp_debug("Receiving rtcp rr packet from unknown ssrc.. discarded");
+            return;
+          }
 
 	    if (msgsize < RTCP_COMMON_HEADER_SIZE + RTCP_SSRC_FIELD_SIZE + (RTCP_REPORT_BLOCK_SIZE*rr->ch.rc))
 	      {
@@ -193,10 +201,51 @@ void rtcp_parse(RtpSession *session, mblk_t *mp)
 	  	  
 	  
 	case RTCP_BYE:
-	  /* to be implemented */
-	  break;
-	  
-	  
+      {
+        rtcp_bye_t *bye = (rtcp_bye_t *) rtcp;
+        unsigned sclen = bye->ch.rc * 4;
+        int reason_space_len = rtcp_pk_size
+                               - sizeof (rtcp_common_header_t)
+                               - sclen;
+        int i;
+        char *reason = NULL;
+        bool_t recv_ssrc_match = FALSE;
+
+        if (reason_space_len < 0) {
+            ortp_debug("Receiving too short RTCP BYE packet... discarded");
+            return;
+        }
+        for (i = 0; i < bye->ch.rc; i++) {
+            if (ntohl(bye->ssrc[i]) == session->recv_ssrc) {
+                recv_ssrc_match = TRUE;
+                break;
+            }
+        }
+        if (recv_ssrc_match) {
+            if (session->on_rtcp_bye.count > 0) {
+                /* Get reason. */
+                if (reason_space_len > 1) {
+                    uint8_t *reasonbuf = (uint8_t *) rtcp
+                                        + sizeof (rtcp_common_header_t)
+                                        + sclen;
+                    if (reasonbuf[0] <= reason_space_len-1)
+                        reason = ortp_strndup((char *)(reasonbuf+1), reasonbuf[0]);
+                    else
+                        ortp_debug("Incorrect RTCP BYE reason length");
+                }
+                rtp_signal_table_emit2(&session->on_rtcp_bye,
+                    (long)reason);
+                if (reason)
+                    ortp_free(reason);
+            } else {
+                ortp_debug("Got RTCP BYE without RTCP BYE handler");
+            }
+        } else {
+            ortp_debug("No SSRC in the BYE packet matched our recv_ssrc.");
+        }
+	    break;
+      }
+
 	case RTCP_APP:
 	  /* to be implemented */
 	  break;
@@ -210,9 +259,12 @@ void rtcp_parse(RtpSession *session, mblk_t *mp)
 	}
 
       
-      rtcp_pk_size = ((rtcp->length)+1)*4;  /* current RTCP packet size, in octets */
       msgsize -= rtcp_pk_size;              /* size of unparsed portion of UDP packet, in octets */
       rtcp = (rtcp_common_header_t *) (rtcp_pk_size + (char *) rtcp);  /* pointer to next RTCP packet in current UDP packet */
 
     }
+
+    /* The function did not failed sanity checks, write down the RTPC/RTCP
+       reception time. */
+    session->last_recv_time = rcv_time_tv;
 }
