@@ -21,11 +21,11 @@
 #ifndef RTPMOD_H
 #define RTPMOD_H
 
-#include <ortp/rtpport.h>
+#include <ortp/port.h>
 #include <ortp/str_utils.h>
 #include <ortp/rtp.h>
 
 void rtp_putq(queue_t *q, mblk_t *mp);
-mblk_t *rtp_getq(queue_t *q,guint32 timestamp, int *rejected);
+mblk_t *rtp_getq(queue_t *q,uint32_t timestamp, int *rejected);
 
 #endif
