@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -21,6 +21,9 @@
 #include <ortp/ortp.h>
 #include "rtpmod.h"
 #include "jitterctl.h"
+#include "utils.h"
+
+extern void rtp_session_update_payload_type(RtpSession * session, int pt);
 
 
 void split_and_queue(queue_t *q, int maxrqsz, mblk_t *mp, rtp_header_t *rtp, int *discarded)
@@ -60,15 +63,15 @@ void split_and_queue(queue_t *q, int maxrqsz, mblk_t *mp, rtp_header_t *rtp, int
 }
 
 
-void rtp_parse(RtpSession *session, mblk_t *mp, guint32 local_str_ts)
+void rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_ts)
 {
-	gint i;
+	int i;
 	rtp_header_t *rtp;
 	int msgsize;
 	RtpStream *rtpstream=&session->rtp;
 	rtp_stats_t *stats=&rtpstream->stats;
 	
-	g_return_if_fail(mp!=NULL);
+	return_if_fail(mp!=NULL);
 	
 	ortp_global_stats.packet_recv++;
 	stats->packet_recv++;
@@ -93,13 +96,17 @@ void rtp_parse(RtpSession *session, mblk_t *mp, guint32 local_str_ts)
 	rtp->timestamp=ntohl(rtp->timestamp);
 	rtp->ssrc=ntohl(rtp->ssrc);
 	/* convert csrc if necessary */
-	if (rtp->cc*sizeof(guint32) > (msgsize-RTP_FIXED_HEADER_SIZE)){
+	if (rtp->cc*sizeof(uint32_t) > (uint32_t) (msgsize-RTP_FIXED_HEADER_SIZE)){
 		ortp_debug("Receiving too short rtp packet.");
 		stats->bad++;
 		ortp_global_stats.bad++;
 		freemsg(mp);
 		return;
 	}
+    
+	/* Write down the last RTP/RTCP packet reception time. */
+	gettimeofday(&session->last_recv_time, NULL);
+
 	for (i=0;i<rtp->cc;i++)
 		rtp->csrc[i]=ntohl(rtp->csrc[i]);
 	if (session->recv_ssrc!=0)
@@ -113,15 +120,17 @@ void rtp_parse(RtpSession *session, mblk_t *mp, guint32 local_str_ts)
 	}else session->recv_ssrc=rtp->ssrc;
 	
 	/* update some statistics */
-	if (rtp->seq_number>rtpstream->hwrcv_extseq.split.lo){
-		rtpstream->hwrcv_extseq.split.lo=rtp->seq_number;
-	}else if (rtp->seq_number<200 && rtpstream->hwrcv_extseq.split.lo>((1<<16) - 200)){
-		/* this is a check for sequence number looping */
-		rtpstream->hwrcv_extseq.split.lo=rtp->seq_number;
-		rtpstream->hwrcv_extseq.split.hi++;
+	{
+		poly32_t *extseq=(poly32_t*)&rtpstream->hwrcv_extseq;
+		if (rtp->seq_number>extseq->split.lo){
+			extseq->split.lo=rtp->seq_number;
+		}else if (rtp->seq_number<200 && extseq->split.lo>((1<<16) - 200)){
+			/* this is a check for sequence number looping */
+			extseq->split.lo=rtp->seq_number;
+			extseq->split.hi++;
+		}
 	}
 	
-	
 	/* check for possible telephone events */
 	if (rtp->paytype==session->telephone_events_pt){
 		split_and_queue(&session->rtp.tev_rq,session->rtp.max_rq_size,mp,rtp,&i);
@@ -130,9 +139,15 @@ void rtp_parse(RtpSession *session, mblk_t *mp, guint32 local_str_ts)
 		return;
 	}
 	
+	/* check for possible payload type change, in order to update accordingly our clock-rate dependant
+	parameters */
+	if (session->hw_recv_pt!=rtp->paytype){
+		rtp_session_update_payload_type(session,rtp->paytype);
+	}
+	
 	if (!(session->flags & RTP_SESSION_RECV_SYNC)){
-		gint32 slide=0;
-		gint32 safe_delay=0;
+		int32_t slide=0;
+		int32_t safe_delay=0;
 		jitter_control_new_packet(&session->rtp.jittctl,rtp->timestamp,local_str_ts,&slide,&safe_delay);
 		
 		session->rtp.rcv_diff_ts=session->rtp.hwrcv_diff_ts + slide - safe_delay;
@@ -141,7 +156,7 @@ void rtp_parse(RtpSession *session, mblk_t *mp, guint32 local_str_ts)
 		/* detect timestamp important jumps in the future, to workaround stupid rtp senders */
 		if (RTP_TIMESTAMP_IS_NEWER_THAN(rtp->timestamp,session->rtp.rcv_last_ts+session->rtp.ts_jump)){
 			ortp_debug("rtp_parse: timestamp jump ?");
-			rtp_signal_table_emit2(&session->on_timestamp_jump,&rtp->timestamp);
+			rtp_signal_table_emit2(&session->on_timestamp_jump,(long)&rtp->timestamp);
 		}
 		else if (RTP_TIMESTAMP_IS_NEWER_THAN(session->rtp.rcv_last_ts,rtp->timestamp)){
 			/* avoid very old packet to enqueued, because the user is no more supposed to get them */
