@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -27,14 +27,14 @@
 #include "winsock2.h"
 #endif
 
-#include <ortp/rtpport.h>
+#include <ortp/port.h>
 
 
 typedef void (*RtpTimerFunc)(void);
 	
 struct _RtpTimer
 {
-	gint state;
+	int state;
 #define RTP_TIMER_RUNNING 1
 #define RTP_TIMER_STOPPED 0
 	RtpTimerFunc timer_init;
