@@ -17,21 +17,12 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _WIN32	/* do not include ortp-config.h when we are on win32 */
-	#include <ortp/rtpport.h>
-	#include <sched.h>
-	#include <unistd.h>
-	#include <errno.h>
-#else
-	#include "ortp-config-win32.h"
-#endif
-
-
-
+#include <ortp/ortp.h>
+#include "utils.h"
 #include "scheduler.h"
 
 // To avoid warning during compile
-extern void rtp_session_process (RtpSession * session, guint32 time, RtpScheduler *sched);
+extern void rtp_session_process (RtpSession * session, uint32_t time, RtpScheduler *sched);
 
 
 void rtp_scheduler_init(RtpScheduler *sched)
@@ -40,9 +31,8 @@ void rtp_scheduler_init(RtpScheduler *sched)
 	sched->time_=0;
 	/* default to the posix timer */
 	rtp_scheduler_set_timer(sched,&posix_timer);
-	sched->lock=g_mutex_new();
-	//sched->unblock_select_mutex=g_mutex_new();
-	sched->unblock_select_cond=g_cond_new();
+	ortp_mutex_init(&sched->lock,NULL);
+	ortp_cond_init(&sched->unblock_select_cond,NULL);
 	sched->max_sessions=sizeof(SessionSet)*8;
 	session_set_init(&sched->all_sessions);
 	sched->all_max=0;
@@ -56,7 +46,7 @@ void rtp_scheduler_init(RtpScheduler *sched)
 
 RtpScheduler * rtp_scheduler_new()
 {
-	RtpScheduler *sched=g_malloc(sizeof(RtpScheduler));
+	RtpScheduler *sched=(RtpScheduler *) ortp_malloc(sizeof(RtpScheduler));
 	memset(sched,0,sizeof(RtpScheduler));
 	rtp_scheduler_init(sched);
 	return sched;
@@ -65,7 +55,7 @@ RtpScheduler * rtp_scheduler_new()
 void rtp_scheduler_set_timer(RtpScheduler *sched,RtpTimer *timer)
 {
 	if (sched->thread_running){
-		g_warning("Cannot change timer while the scheduler is running !!");
+		ortp_warning("Cannot change timer while the scheduler is running !!");
 		return;
 	}
 	sched->timer=timer;
@@ -77,12 +67,12 @@ void rtp_scheduler_start(RtpScheduler *sched)
 {
 	if (sched->thread_running==0){
 		sched->thread_running=1;
-		g_mutex_lock(sched->lock);
-		sched->thread=g_thread_create((GThreadFunc)rtp_scheduler_schedule,(gpointer)sched,TRUE,NULL);
-		g_cond_wait(sched->unblock_select_cond,sched->lock);
-		g_mutex_unlock(sched->lock);
+		ortp_mutex_lock(&sched->lock);
+		ortp_thread_create(&sched->thread, NULL, rtp_scheduler_schedule,(void*)sched);
+		ortp_cond_wait(&sched->unblock_select_cond,&sched->lock);
+		ortp_mutex_unlock(&sched->lock);
 	}
-	else g_warning("Scheduler thread already running.");
+	else ortp_warning("Scheduler thread already running.");
 
 }
 void rtp_scheduler_stop(RtpScheduler *sched)
@@ -90,66 +80,66 @@ void rtp_scheduler_stop(RtpScheduler *sched)
 	if (sched->thread_running==1)
 	{
 		sched->thread_running=0;
-		g_thread_join(sched->thread);
+		ortp_thread_join(sched->thread, NULL);
 	}
-	else g_warning("Scheduler thread is not running.");
+	else ortp_warning("Scheduler thread is not running.");
 }
 
 void rtp_scheduler_destroy(RtpScheduler *sched)
 {
 	if (sched->thread_running) rtp_scheduler_stop(sched);
-	g_mutex_free(sched->lock);
+	ortp_mutex_destroy(&sched->lock);
 	//g_mutex_free(sched->unblock_select_mutex);
-	g_cond_free(sched->unblock_select_cond);
-	g_free(sched);
+	ortp_cond_destroy(&sched->unblock_select_cond);
+	ortp_free(sched);
 }
 
-gpointer rtp_scheduler_schedule(gpointer psched)
+void * rtp_scheduler_schedule(void * psched)
 {
 	RtpScheduler *sched=(RtpScheduler*) psched;
 	RtpTimer *timer=sched->timer;
 	RtpSession *current;
-	int err;
 
 	/* try to get the real time priority by getting root*/
 #ifndef _WIN32
+	
+	int err;
+
 #ifdef HAVE_SETEUID
 	err=seteuid(0);
 #else
 	err=setuid(0);
 #endif
-	if (err<0) g_message("Could not get root euid: %s",strerror(errno));
+	if (err<0) ortp_message("Could not get root euid: %s",strerror(errno));
 #endif
-	g_message("scheduler: trying to reach real time kernel scheduling...");
+	ortp_message("scheduler: trying to reach real time kernel scheduling...");
 
 	/* take this lock to prevent the thread to start until g_thread_create() returns
 		because we need sched->thread to be initialized */
-	g_mutex_lock(sched->lock);
-	g_cond_signal(sched->unblock_select_cond);	/* unblock the starting thread */
-	g_mutex_unlock(sched->lock);
-	g_thread_set_priority(sched->thread,G_THREAD_PRIORITY_HIGH);
+	ortp_mutex_lock(&sched->lock);
+	ortp_cond_signal(&sched->unblock_select_cond);	/* unblock the starting thread */
+	ortp_mutex_unlock(&sched->lock);
 	timer->timer_init();
 	while(sched->thread_running)
 	{
 		/* do the processing here: */
-		
-		g_mutex_lock(sched->lock);
+		ortp_mutex_lock(&sched->lock);
 		
 		current=sched->list;
 		/* processing all scheduled rtp sessions */
 		while (current!=NULL)
 		{
-			ortp_debug("scheduler: processing session=%p.\n",current);
+			ortp_debug("scheduler: processing session=0x%x.\n",current);
 			rtp_session_process(current,sched->time_,sched);
 			current=current->next;
 		}
 		/* wake up all the threads that are sleeping in _select()  */
-		g_cond_broadcast(sched->unblock_select_cond);
-		g_mutex_unlock(sched->lock);
+		ortp_cond_broadcast(&sched->unblock_select_cond);
+		ortp_mutex_unlock(&sched->lock);
 		
 		/* now while the scheduler is going to sleep, the other threads can compute their
 		result mask and see if they have to leave, or to wait for next tick*/
-		//g_message("scheduler: sleeping.");
+		//ortp_message("scheduler: sleeping.");
 		timer->timer_do();
 		sched->time_+=sched->timer_inc;
 	}
@@ -172,7 +162,7 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
 	sched->list=session;
 	session->next=oldfirst;
 	if (sched->max_sessions==0){
-		g_error("rtp_scheduler_add_session: max_session=0 !");
+		ortp_error("rtp_scheduler_add_session: max_session=0 !");
 	}
 	/* find a free pos in the session mask*/
 	for (i=0;i<sched->max_sessions;i++){
@@ -199,7 +189,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
 {
 	RtpSession *tmp;
 	int cond=1;
-	g_return_if_fail(session!=NULL); 
+	return_if_fail(session!=NULL); 
 	if (!(session->flags & RTP_SESSION_IN_SCHEDULER)){
 		/* the rtp session is not scheduled, so return silently */
 		return;
@@ -224,7 +214,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
 			else tmp=tmp->next;
 		}else {
 			/* the session was not found ! */
-			g_warning("rtp_scheduler_remove_session: the session was not found in the scheduler list!");
+			ortp_warning("rtp_scheduler_remove_session: the session was not found in the scheduler list!");
 			cond=0;
 		}
 	}
