@@ -40,7 +40,7 @@
 **/
 SessionSet * session_set_new()
 {
-	SessionSet *set=g_malloc(sizeof(SessionSet));
+	SessionSet *set=(SessionSet *) ortp_malloc(sizeof(SessionSet));
 	session_set_init(set);
 	return set;
 }
@@ -55,17 +55,17 @@ SessionSet * session_set_new()
 
 void session_set_destroy(SessionSet *set)
 {
-	g_free(set);
+	ortp_free(set);
 }
 
-gint session_set_and(SessionSet *sched_set, gint maxs, SessionSet *user_set, SessionSet *result_set)
+int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, SessionSet *result_set)
 {
-	guint32 *mask1,*mask2,*mask3;
-	gint i=0;
-	gint j,ret=0;
-	mask1=(guint32*)&sched_set->rtpset;
-	mask2=(guint32*)&user_set->rtpset;
-	mask3=(guint32*)&result_set->rtpset;
+	uint32_t *mask1,*mask2,*mask3;
+	int i=0;
+	int j,ret=0;
+	mask1=(uint32_t*)&sched_set->rtpset;
+	mask2=(uint32_t*)&user_set->rtpset;
+	mask3=(uint32_t*)&result_set->rtpset;
 	while(i<maxs+1){
 		*mask3=(*mask1) & (*mask2);	/* computes the AND between the two masks*/
 		/* and unset the sessions that have been found from the sched_set */
@@ -112,7 +112,7 @@ gint session_set_and(SessionSet *sched_set, gint maxs, SessionSet *user_set, Ses
 **/
 int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 {
-	gint ret=0,bits;
+	int ret=0,bits;
 	SessionSet temp;
 	RtpScheduler *sched=ortp_get_scheduler();
 	
@@ -154,7 +154,7 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 		}
 		//printf("There are %i sessions set.\n",ret);
 		/* else we wait until the next loop of the scheduler*/
-		g_cond_wait(sched->unblock_select_cond,sched->lock);
+		ortp_cond_wait(&sched->unblock_select_cond,&sched->lock);
 	}
 
 	return -1;
