@@ -17,17 +17,15 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <ortp/rtpport.h>
-#include <ortp/rtp.h>
-#include <ortp/str_utils.h>
-
-#include <stdio.h>
+#include "ortp/port.h"
+#include "ortp/rtp.h"
+#include "ortp/str_utils.h"
+#include "utils.h"
 
 void qinit(queue_t *q){
-	mblk_init(&q->_q_first);
-	mblk_init(&q->_q_last);
-	q->_q_first.b_next=&q->_q_last;
-	q->_q_last.b_prev=&q->_q_first;
+	mblk_init(&q->_q_stopper);
+	q->_q_stopper.b_next=&q->_q_stopper;
+	q->_q_stopper.b_prev=&q->_q_stopper;
 	q->q_mcount=0;
 }
 
@@ -35,27 +33,46 @@ void mblk_init(mblk_t *mp)
 {
 	mp->b_cont=mp->b_prev=mp->b_next=NULL;
 	mp->b_rptr=mp->b_wptr=NULL;
+	mp->reserved1=0;
+	mp->reserved2=0;
 }
 
+dblk_t *datab_alloc(int size){
+	dblk_t *db;
+	int total_size=sizeof(dblk_t)+size;
+	db=(dblk_t *) ortp_malloc(total_size);
+	db->db_base=((char*)db)+sizeof(dblk_t);
+	db->db_lim=db->db_base+size;
+	db->ref_count=1;
+	db->db_freefn=NULL;	/* the buffer pointed by db_base must never be freed !*/
+	return db;
+}
+
+static inline void datab_ref(dblk_t *d){
+	d->ref_count++;
+}
+
+static inline void datab_unref(dblk_t *d){
+	d->ref_count--;
+	if (d->ref_count==0){
+		if (d->db_freefn!=NULL)
+			d->db_freefn(d->db_base);
+		ortp_free(d);
+	}
+}
+
+
 mblk_t *allocb(int size, int pri)
 {
 	mblk_t *mp;
 	dblk_t *datab;
-	gchar *buf;
 	
-	mp=g_malloc(sizeof(mblk_t));
+	mp=(mblk_t *) ortp_malloc(sizeof(mblk_t));
 	mblk_init(mp);
-	datab=g_malloc(sizeof(dblk_t));
-	
-	buf=g_malloc(size);
-
-	datab->db_base=buf;
-	datab->db_lim=buf+size;
-	datab->ref_count=1;
-	datab->db_freefn=g_free;
+	datab=datab_alloc(size);
 	
 	mp->b_datap=datab;
-	mp->b_rptr=mp->b_wptr=buf;
+	mp->b_rptr=mp->b_wptr=datab->db_base;
 	mp->b_next=mp->b_prev=mp->b_cont=NULL;
 	return mp;
 }
@@ -65,9 +82,9 @@ mblk_t *allocb_with_buf(char *buf, int size, int pri, void (*freefn)(void*) )
 	mblk_t *mp;
 	dblk_t *datab;
 	
-	mp=g_malloc(sizeof(mblk_t));
+	mp=(mblk_t *) ortp_malloc(sizeof(mblk_t));
 	mblk_init(mp);
-	datab=g_malloc(sizeof(dblk_t));
+	datab=(dblk_t *) ortp_malloc(sizeof(dblk_t));
 	
 
 	datab->db_base=buf;
@@ -84,18 +101,11 @@ mblk_t *allocb_with_buf(char *buf, int size, int pri, void (*freefn)(void*) )
 	
 void freeb(mblk_t *mp)
 {
-	g_return_if_fail(mp->b_datap!=NULL);
-	g_return_if_fail(mp->b_datap->db_base!=NULL);
+	return_if_fail(mp->b_datap!=NULL);
+	return_if_fail(mp->b_datap->db_base!=NULL);
 	
-	mp->b_datap->ref_count--;
-	if (mp->b_datap->ref_count==0)
-	{
-		if (mp->b_datap->db_freefn!=NULL)
-			mp->b_datap->db_freefn(mp->b_datap->db_base);
-		
-		g_free(mp->b_datap);
-	}
-	g_free(mp);
+	datab_unref(mp->b_datap);
+	ortp_free(mp);
 }	
 
 void freemsg(mblk_t *mp)
@@ -113,11 +123,11 @@ void freemsg(mblk_t *mp)
 mblk_t *dupb(mblk_t *mp)
 {
 	mblk_t *newm;
-	g_return_val_if_fail(mp->b_datap!=NULL,NULL);
-	g_return_val_if_fail(mp->b_datap->db_base!=NULL,NULL);
+	return_val_if_fail(mp->b_datap!=NULL,NULL);
+	return_val_if_fail(mp->b_datap->db_base!=NULL,NULL);
 	
-	mp->b_datap->ref_count++;
-	newm=g_malloc(sizeof(mblk_t));
+	datab_ref(mp->b_datap);
+	newm=(mblk_t *) ortp_malloc(sizeof(mblk_t));
 	mblk_init(newm);
 	newm->b_datap=mp->b_datap;
 	newm->b_rptr=mp->b_rptr;
@@ -142,26 +152,33 @@ mblk_t	*dupmsg(mblk_t* m)
 
 void putq(queue_t *q,mblk_t *mp)
 {
-	q->_q_last.b_prev->b_next=mp;
-	mp->b_prev=q->_q_last.b_prev;
-	mp->b_next=&q->_q_last;
-	q->_q_last.b_prev=mp;
+	q->_q_stopper.b_prev->b_next=mp;
+	mp->b_prev=q->_q_stopper.b_prev;
+	mp->b_next=&q->_q_stopper;
+	q->_q_stopper.b_prev=mp;
 	q->q_mcount++;
 }
 
 mblk_t *getq(queue_t *q)
 {
 	mblk_t *tmp;
-	tmp=q->_q_first.b_next;
-	if (tmp==&q->_q_last) return NULL;
-	q->_q_first.b_next=tmp->b_next;
-	tmp->b_next->b_prev=&q->_q_first;
+	tmp=q->_q_stopper.b_next;
+	if (tmp==&q->_q_stopper) return NULL;
+	q->_q_stopper.b_next=tmp->b_next;
+	tmp->b_next->b_prev=&q->_q_stopper;
 	tmp->b_prev=NULL;
 	tmp->b_next=NULL;
 	q->q_mcount--;
 	return tmp;
 }
 
+mblk_t * peekq(queue_t *q){
+	mblk_t *tmp;
+	tmp=q->_q_stopper.b_next;
+	if (tmp==&q->_q_stopper) return NULL;
+	return tmp;
+}
+
 /* insert mp in q just before emp */
 void insq(queue_t *q,mblk_t *emp, mblk_t *mp)
 {
@@ -195,56 +212,55 @@ void flushq(queue_t *q, int how)
 	}
 }
 
-gint msgdsize(mblk_t *mp)
+int msgdsize(mblk_t *mp)
 {
-	gint msgsize=0;
+	int msgsize=0;
 	while(mp!=NULL){
-		msgsize+=mp->b_wptr-mp->b_rptr;
+		msgsize+=(int) (mp->b_wptr-mp->b_rptr);
 		mp=mp->b_cont;
 	}
 	return msgsize;
 }
 
-mblk_t * msgpullup(mblk_t *mp,int len)
+void msgpullup(mblk_t *mp,int len)
 {
-	mblk_t *newm;
-	gint msgsize=msgdsize(mp);
-	gint rlen;
-	gint mlen;
+	mblk_t *firstm=mp;
+	dblk_t *db;
+	int msgsize;
+	int wlen=0;
 	
+	if (mp->b_cont==NULL) return;	/*nothing to do, message is not fragmented */
 	
+	msgsize=msgdsize(mp);
 	if ((len==-1) || (len>msgsize)) len=msgsize;
-	rlen=len;
-	newm=allocb(len,BPRI_MED);
+	db=datab_alloc(len);
 
-	while(mp!=NULL){
-		mlen=mp->b_wptr-mp->b_rptr;
-		if (rlen>=mlen)
-		{
-			memcpy(newm->b_wptr,mp->b_rptr,mlen);
-			rlen-=mlen;
-			newm->b_wptr+=mlen;
+	while(wlen<len){
+		int remain=len-wlen;
+		int mlen=mp->b_wptr-mp->b_rptr;
+		if (mlen<=remain){
+			memcpy(&db->db_base[wlen],mp->b_rptr,mlen);
+			wlen+=mlen;
+			mp=mp->b_cont;
+		}else{
+			memcpy(&db->db_base[wlen],mp->b_rptr,remain);
+			wlen+=remain;
 		}
-		else /* rlen < mlen */
-		{
-			memcpy(newm->b_wptr,mp->b_rptr,rlen);
-			newm->b_wptr+=rlen;
-			
-			/* put the end of the original message at the end of the new */
-			newm->b_cont=dupmsg(mp);
-			newm->b_cont->b_rptr+=rlen;
-			return newm;
-		}
-		mp=mp->b_cont;
 	}
-	return newm;
+	/*set firstm to point to the new datab */
+	freemsg(firstm->b_cont);
+	firstm->b_cont=NULL;
+	datab_unref(firstm->b_datap);
+	firstm->b_datap=db;
+	firstm->b_rptr=db->db_base;
+	firstm->b_wptr=db->db_lim;
 }
 
 
 mblk_t *copyb(mblk_t *mp)
 {
 	mblk_t *newm;
-	gint len=mp->b_wptr-mp->b_rptr;
+	int len=(int) (mp->b_wptr-mp->b_rptr);
 	newm=allocb(len,BPRI_MED);
 	memcpy(newm->b_wptr,mp->b_rptr,len);
 	newm->b_wptr+=len;
@@ -264,15 +280,15 @@ mblk_t *copymsg(mblk_t *mp)
 	return newm;
 }
 
-mblk_t * appendb(mblk_t *mp, const char *data, int size, gboolean pad){
-	gint padcnt=0;
+mblk_t * appendb(mblk_t *mp, const char *data, int size, bool_t pad){
+	int padcnt=0;
 	int i;
 	if (pad){
-		padcnt= (gint)(4L-( (long)(mp->b_wptr+size) % 4L)) % 4L;
+		padcnt= (int)(4L-( (long)(((long)mp->b_wptr)+size) % 4L)) % 4L;
 	}
 	if ((mp->b_wptr + size +padcnt) > (char*)mp->b_datap->db_lim){
 		/* buffer is not large enough: append a new block (with the same size ?)*/
-		int plen=(char*)mp->b_datap->db_lim - (char*) mp->b_datap->db_base;
+		int plen=(int)((char*)mp->b_datap->db_lim - (char*) mp->b_datap->db_base);
 		mp->b_cont=allocb(MAX(plen,size),0);
 		mp=mp->b_cont;
 	}
@@ -285,7 +301,7 @@ mblk_t * appendb(mblk_t *mp, const char *data, int size, gboolean pad){
 	return mp;
 }
 
-void msgappend(mblk_t *mp, const char *data, int size, gboolean pad){
+void msgappend(mblk_t *mp, const char *data, int size, bool_t pad){
 	while(mp->b_cont!=NULL) mp=mp->b_cont;
 	appendb(mp,data,size,pad);
 }
