@@ -18,7 +18,8 @@
 */
 
 #include <ortp/telephonyevents.h>
-
+#include "utils.h"
+#include <ortp/ortp.h>
 
 PayloadType	payload_type_telephone_event={
 	PAYLOAD_AUDIO_PACKETIZED, /*type */
@@ -42,10 +43,11 @@ PayloadType	payload_type_telephone_event={
  *
  *Returns: the payload type number used for telephony events if found, -1 if not found.
 **/
-gint rtp_session_telephone_events_supported(RtpSession *session)
+int rtp_session_telephone_events_supported(RtpSession *session)
 {
 	/* search for a telephony event payload in the current profile */
 	session->telephone_events_pt=rtp_profile_get_payload_number_from_mime(session->profile,"telephone-event");
+	/*printf("Telephone event pt is %i\n",session->telephone_events_pt);*/
 	return session->telephone_events_pt;
 }
 
@@ -68,7 +70,7 @@ mblk_t	*rtp_session_create_telephone_event_packet(RtpSession *session, int start
 	mblk_t *mp;
 	rtp_header_t *rtp;
 	
-	g_return_val_if_fail(session->telephone_events_pt!=-1,NULL);
+	return_val_if_fail(session->telephone_events_pt!=-1,NULL);
 	
 	mp=allocb(RTP_FIXED_HEADER_SIZE+TELEPHONY_EVENTS_ALLOCATED_SIZE,BPRI_MED);
 	if (mp==NULL) return NULL;
@@ -105,8 +107,8 @@ mblk_t	*rtp_session_create_telephone_event_packet(RtpSession *session, int start
  *
  *Returns 0 on success.
 **/
-gint rtp_session_add_telephone_event(RtpSession *session,
-			mblk_t *packet, guchar event, gint end, guchar volume, guint16 duration)
+int rtp_session_add_telephone_event(RtpSession *session,
+			mblk_t *packet, uint8_t event, int end, uint8_t volume, uint16_t duration)
 {
 	mblk_t *mp=packet;
 	telephone_event_t *event_hdr;
@@ -115,7 +117,7 @@ gint rtp_session_add_telephone_event(RtpSession *session,
 	/* find the place where to add the new telephony event to the packet */
 	while(mp->b_cont!=NULL) mp=mp->b_cont;
 	/* see if we need to allocate a new mblk_t */
-	if ( (long)mp->b_wptr >= (long) mp->b_datap->db_lim){
+	if ( ( mp->b_wptr) >= (mp->b_datap->db_lim)){
 		mblk_t *newm=allocb(TELEPHONY_EVENTS_ALLOCATED_SIZE,BPRI_MED);
 		mp->b_cont=newm;
 		mp=mp->b_cont;
@@ -144,7 +146,7 @@ gint rtp_session_add_telephone_event(RtpSession *session,
  *Returns:	0 if successfull, -1 if the session cannot support telephony events or if the dtmf
  *	given as argument is not valid.
 **/
-gint rtp_session_send_dtmf(RtpSession *session, gchar dtmf, guint32 userts)
+int rtp_session_send_dtmf(RtpSession *session, char dtmf, uint32_t userts)
 {
 	mblk_t *m1,*m2,*m3;
 	int tev_type;
@@ -187,7 +189,7 @@ gint rtp_session_send_dtmf(RtpSession *session, gchar dtmf, guint32 userts)
 			tev_type=TEV_DTMF_POUND;
 		break;
 		default:
-		g_warning("Bad dtmf: %c.",dtmf);
+		ortp_warning("Bad dtmf: %c.",dtmf);
 		return -1;
 	}
 
@@ -235,15 +237,15 @@ gint rtp_session_send_dtmf(RtpSession *session, gchar dtmf, guint32 userts)
  *Returns: the number of events in the packet if successfull, 0 if the packet did not
  *	contain telephony events.
 **/
-gint rtp_session_read_telephone_event(RtpSession *session,
+int rtp_session_read_telephone_event(RtpSession *session,
 		mblk_t *packet,telephone_event_t **tab)
 {
 	int datasize;
-	gint num;
+	int num;
 	int i;
 	telephone_event_t *tev;
 	rtp_header_t *hdr=(rtp_header_t*)packet->b_rptr;
-	g_return_val_if_fail(packet->b_cont!=NULL,-1);
+	return_val_if_fail(packet->b_cont!=NULL,-1);
 	if (hdr->paytype!=session->telephone_events_pt) return 0;  /* this is not tel ev.*/
 	datasize=msgdsize(packet);
 	tev=*tab=(telephone_event_t*)packet->b_cont->b_rptr;
@@ -261,7 +263,7 @@ static void notify_events_ended(RtpSession *session, telephone_event_t *events,
 	int i;
 	for (i=0;i<num;i++){
 		if (events[i].E==1){
-			rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(long)events[i].event);
+			rtp_signal_table_emit2(&session->on_telephone_event,(long)(long)events[i].event);
 		}
 	}
 }
@@ -279,7 +281,7 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 	hdr=(rtp_header_t*)m0->b_rptr;
 	mp=m0->b_cont;
 	
-	num=(mp->b_wptr-mp->b_rptr)/sizeof(telephone_event_t);
+	num=((int)(mp->b_wptr-mp->b_rptr))/sizeof(telephone_event_t);
 	events=(telephone_event_t*)mp->b_rptr;
 	
 	
@@ -311,7 +313,7 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 					if (evbuf[i].E==0){
 						evbuf[i].E=1;
 						/* this is a end of event, report it */
-						rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(long)events[i].event);
+						rtp_signal_table_emit2(&session->on_telephone_event,(long)(long)events[i].event);
 					}
 				}
 			}
