@@ -27,7 +27,7 @@
 #include <sys/types.h>
 #endif
 
-gint cond=1;
+int cond=1;
 
 void stop_handler(int signum)
 {
@@ -48,7 +48,7 @@ static char *help="usage: rtprecv  filename loc_port [--format format] [--soundc
 
 #include <sys/audio.h>
 
-gint sound_init(gint format)
+int sound_init(int format)
 {
 	int fd;
 	fd=open("/dev/audio",O_WRONLY);
@@ -65,7 +65,7 @@ gint sound_init(gint format)
 	return fd;	
 }
 #else
-gint sound_init(gint format)
+int sound_init(int format)
 {
 	return -1;
 }
@@ -76,16 +76,16 @@ int main(int argc, char*argv[])
 	RtpSession *session;
 	char buffer[160];
 	int err;
-	guint32 ts=0;
-	gint stream_received=0;
+	uint32_t ts=0;
+	int stream_received=0;
 	FILE *outfile;
-	gint local_port;
-	gint have_more;
-	gint i;
-	gint format=0;
-	gint soundcard=0;
-	gint sound_fd=0;
-	gboolean adapt=TRUE;
+	int local_port;
+	int have_more;
+	int i;
+	int format=0;
+	int soundcard=0;
+	int sound_fd=0;
+	bool_t adapt=TRUE;
 	
 	/* init the lib */
 	if (argc<3){
@@ -134,7 +134,6 @@ int main(int argc, char*argv[])
 	ortp_scheduler_init();
 	
 	signal(SIGINT,stop_handler);
-	ortp_set_debug_file("oRTP",stdout);
 	session=rtp_session_new(RTP_SESSION_RECVONLY);	
 	rtp_session_set_scheduling_mode(session,1);
 	rtp_session_set_blocking_mode(session,1);
@@ -142,8 +141,8 @@ int main(int argc, char*argv[])
 	rtp_session_enable_adaptive_jitter_compensation(session,adapt);
 	rtp_session_set_jitter_compensation(session,40);
 	rtp_session_set_payload_type(session,0);
-	rtp_session_signal_connect(session,"ssrc_changed",(RtpCallback)ssrc_cb,NULL);
-	rtp_session_signal_connect(session,"ssrc_changed",(RtpCallback)rtp_session_reset,NULL);
+	rtp_session_signal_connect(session,"ssrc_changed",(RtpCallback)ssrc_cb,0);
+	rtp_session_signal_connect(session,"ssrc_changed",(RtpCallback)rtp_session_reset,0);
 	
 	while(cond)
 	{
@@ -153,12 +152,13 @@ int main(int argc, char*argv[])
 			if (err>0) stream_received=1;
 			/* this is to avoid to write to disk some silence before the first RTP packet is returned*/	
 			if ((stream_received) && (err>0)) {
-				fwrite(buffer,1,err,outfile);
-				if (sound_fd>0) write(sound_fd,buffer,err);
+				size_t ret = fwrite(buffer,1,err,outfile);
+				if (sound_fd>0)
+					ret = write(sound_fd,buffer,err);
 			}
 		}
 		ts+=160;
-		//g_message("Receiving packet.");
+		//ortp_message("Receiving packet.");
 	}
 	
 	rtp_session_destroy(session);
