@@ -23,6 +23,7 @@
 #include <ortp/ortp.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <assert.h>
 
 #ifndef _WIN32
 #include <signal.h>
@@ -57,26 +58,28 @@ static char *help="usage: tevmrtprecv	file_prefix local_port number_of_streams \
 #define STREAMS_COUNT 1000
 
 
-void recv_tev_cb(RtpSession *session,gint type,gpointer user_data)
+void recv_tev_cb(RtpSession *session,int type,long user_data)
 {
         //printf("Receiving telephony event:%i\n",type);
         if (type<16) printf("This is dtmf %c on channel %d\n",dtmf_tab[type],*(int *)user_data);
         dtmf_count++;
 }
 
-int rtp2disk(RtpSession *session,guint32 ts, int fd)
+int rtp2disk(RtpSession *session,uint32_t ts, int fd)
 {
 	char buffer[160];
 	int err,havemore=1;
 	while (havemore){
 		err=rtp_session_recv_with_ts(session,buffer,160,ts,&havemore);
 		if (err>0){
-			rtp_session_set_data(session,(gpointer)1);
+			rtp_session_set_data(session,(void*)1);
 			/* to indicate that (for the application) the stream has started, so we can start
 			recording on disk */
 		}
-		if (session->user_data != NULL)
-			write(fd,buffer,err);
+		if (session->user_data != NULL) {
+			size_t ret = write(fd,buffer,err);
+			assert( ret == err );
+		}
 	}
 	return 0;
 }
@@ -85,13 +88,13 @@ int rtp2disk(RtpSession *session,guint32 ts, int fd)
 int main(int argc, char *argv[])
 {
 	RtpSession *session[STREAMS_COUNT];
-	gint i;
-	gint filefd[STREAMS_COUNT];
-	gint port;
-	guint32 user_ts=0;
-	gint channels;
+	int i;
+	int filefd[STREAMS_COUNT];
+	int port;
+	uint32_t user_ts=0;
+	int channels;
 	SessionSet *set;
-	gchar *filename;
+	char *filename;
 
 	if (argc<4){
 		printf(help);
@@ -106,13 +109,12 @@ int main(int argc, char *argv[])
 	
 	ortp_init();
 	ortp_scheduler_init();
-	ortp_set_debug_file("oRTP",NULL);
 	
         /* set the telephony event payload type to 96 in the av profile.*/
         rtp_profile_set_payload(&av_profile,96,&payload_type_telephone_event);
 
 	port=atoi(argv[2]);
-	p_channel_id = (int *)g_malloc(channels*sizeof(int));
+	p_channel_id = (int *)ortp_malloc(channels*sizeof(int));
 	for (i=0;i<channels;i++){
 		session[i]=rtp_session_new(RTP_SESSION_RECVONLY);	
 		rtp_session_set_scheduling_mode(session[i],1);
@@ -120,16 +122,16 @@ int main(int argc, char *argv[])
 
 		rtp_session_set_local_addr(session[i],"0.0.0.0",port);
 		rtp_session_set_recv_payload_type(session[i],0);
-		rtp_session_max_buf_size_set(session[i],256);
+		rtp_session_set_recv_buf_size(session[i],256);
 
 		p_channel_id[i] = i;
 		/* register for telephony events */
-		rtp_session_signal_connect(session[i],"telephone-event",(RtpCallback)recv_tev_cb,&p_channel_id[i]);
+		rtp_session_signal_connect(session[i],"telephone-event",(RtpCallback)recv_tev_cb,(long)&p_channel_id[i]);
 
 		port+=2;
 	}
 		
-	filename=g_malloc(strlen(argv[1])+8);
+	filename=ortp_malloc(strlen(argv[1])+8);
 	for (i=0;i<channels;i++){
 		sprintf(filename,"%s%4.4d.dat",argv[1],i);
 		#ifndef _WIN32
@@ -137,7 +139,7 @@ int main(int argc, char *argv[])
 		#else
 		filefd[i]=open(filename,_O_BINARY | O_WRONLY | O_CREAT | O_TRUNC);
 		#endif
-		if (filefd[i]<0) g_error("Could not open %s for writing: %s",filename,strerror(errno));
+		if (filefd[i]<0) ortp_error("Could not open %s for writing: %s",filename,strerror(errno));
 	}
 	signal(SIGINT,stophandler);
 	/* create a set */
@@ -165,8 +167,8 @@ int main(int argc, char *argv[])
 		rtp_session_destroy(session[i]);
 	}
 	session_set_destroy(set);
-	g_free(p_channel_id);
-	g_free(filename);
+	ortp_free(p_channel_id);
+	ortp_free(filename);
 	ortp_exit();
 	ortp_global_stats_display();
 	return 0;
