@@ -45,8 +45,8 @@ int main(int argc, char *argv[])
 	int i;
 	FILE *infile;
 	char *ssrc;
-	guint32 user_ts=0;
-	gint tel=0;
+	uint32_t user_ts=0;
+	int tel=0;
 	
 	if (argc<4){
 		printf(help);
@@ -55,7 +55,6 @@ int main(int argc, char *argv[])
 	
 	ortp_init();
 	ortp_scheduler_init();
-	ortp_set_debug_file("oRTP",stdout);
 	
 	/* set the telephony event payload type to 96 in the av profile.*/
 	rtp_profile_set_payload(&av_profile,96,&payload_type_telephone_event);
@@ -81,13 +80,13 @@ int main(int argc, char *argv[])
 	signal(SIGINT,stophandler);
 	while( ((i=fread(buffer,1,160,infile))>0) && (runcond) )
 	{
-		//g_message("Sending packet.");
+		//ortp_message("Sending packet.");
 		rtp_session_send_with_ts(session,buffer,i,user_ts);
 		user_ts+=160;
 		tel++;
 		if (tel==50){
 			tel=0;
-			g_message("Sending telephony event packet.");
+			ortp_message("Sending telephony event packet.");
 			rtp_session_send_dtmf(session,'*',user_ts);
 			user_ts+=160+160+160; /* the duration of the dtmf */
 		}
