@@ -20,6 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifndef _WIN32
 
 #include <string.h>
 
@@ -646,3 +647,5 @@ g_shell_parse_argv (const gchar *command_line,
   
   return FALSE;
 }
+
+#endif
