@@ -21,6 +21,9 @@
  */
 
 #include "uglib.h"
+
+#ifndef _WIN32
+
 #define _(str) (str)
 
 #include <sys/time.h>
@@ -1512,3 +1515,5 @@ g_execute (const gchar *file,
   /* Return the error from the last attempt (probably ENOENT).  */
   return -1;
 }
+
+#endif /*_WIN32*/
